@@ -23,6 +23,16 @@ OC.L10N.register(
     "Sharing" : "Roinnt",
     "Federated file sharing" : "Comhroinnt chónaidhme",
     "Provide federated file sharing across servers" : "Comhroinnt comhad cónasctha a sholáthar thar freastalaithe",
+    "Confirm data upload to lookup server" : "Deimhnigh uaslódáil sonraí chuig an bhfreastalaí cuardaigh",
+    "When enabled, all account properties (e.g. email address) with scope visibility set to \"published\", will be automatically synced and transmitted to an external system and made available in a public, global address book." : "Nuair a bheidh sé cumasaithe, déanfar gach maoin chuntais (m.sh. seoladh ríomhphoist) a bhfuil scóip infheictheachta aici “foilsithe”, a shioncronú go huathoibríoch agus a tharchur chuig córas seachtrach agus cuirfear ar fáil iad i leabhar seoltaí poiblí domhanda.",
+    "Disable upload" : "Díchumasaigh uaslódáil",
+    "Enable data upload" : "Cumasaigh uaslódáil sonraí",
+    "Confirm querying lookup server" : "Deimhnigh an freastalaí cuardaigh fiosraithe",
+    "When enabled, the search input when creating shares will be sent to an external system that provides a public and global address book." : "Nuair a bheidh sé cumasaithe, seolfar an t-ionchur cuardaigh agus scaireanna á gcruthú chuig córas seachtrach a sholáthraíonn leabhar seoltaí poiblí agus domhanda.",
+    "This is used to retrieve the federated cloud ID to make federated sharing easier." : "Úsáidtear é seo chun an ID scamall cónasctha a aisghabháil chun comhroinnt chónasctha a dhéanamh níos éasca.",
+    "Moreover, email addresses of users might be sent to that system in order to verify them." : "Ina theannta sin, d’fhéadfaí seoltaí ríomhphoist úsáideoirí a sheoladh chuig an gcóras sin chun iad a fhíorú.",
+    "Disable querying" : "Díchumasaigh an cheistiú",
+    "Enable querying" : "Cumasaigh fiosrú",
     "Unable to update federated files sharing config" : "Ní féidir an chumraíocht chomhroinnte comhad a nuashonrú",
     "Adjust how people can share between servers. This includes shares between people on this server as well if they are using federated sharing." : "Coigeartaigh conas is féidir le daoine roinnt idir freastalaithe. Áirítear leis seo scaireanna idir daoine ar an bhfreastalaí seo freisin má tá comhroinnt chónaidhmeach á úsáid acu.",
     "Allow people on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Lig do dhaoine ar an bhfreastalaí seo scaireanna a sheoladh chuig freastalaithe eile ( ceadaíonn an rogha seo rochtain WebDAV ar scaireanna poiblí freisin)",
@@ -36,6 +46,7 @@ OC.L10N.register(
     "Automatically accept shares from trusted federated accounts and groups by default" : "Glac go huathoibríoch le scaireanna ó chuntais chónaidhme iontaofa agus ó ghrúpaí de réir réamhshocraithe",
     "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "Roinn liom trí m'aitheantas scamall #Nextcloud Federated Cloud, féach {url}",
     "Share with me through my #Nextcloud Federated Cloud ID" : "Roinn liom trí m'aitheantas scamall #Nextcloud Federated Cloud",
+    "Share with me via Nextcloud" : "Roinn liom trí Nextcloud",
     "Cloud ID copied to the clipboard" : "Cóipeáladh Cloud ID chuig an ngearrthaisce",
     "Copy to clipboard" : "Cóipeáil chuig an ngearrthaisce",
     "Clipboard not available. Please copy the cloud ID manually." : "Níl an gearrthaisce ar fáil. Cóipeáil an t-aitheantas néil de láimh.",
@@ -49,17 +60,12 @@ OC.L10N.register(
     "formerly Twitter" : "Twitter roimhe seo",
     "Mastodon" : "Mastodon",
     "Add to your website" : "Cuir le do láithreán gréasáin",
-    "Share with me via Nextcloud" : "Roinn liom trí Nextcloud",
     "HTML Code:" : "Cód HTML:",
     "Cancel" : "Cealaigh",
     "Add remote share" : "Cuir cianroinnte leis",
     "Remote share" : "Comhroinnt iargúlta",
     "Do you want to add the remote share {name} from {owner}@{remote}?" : "Ar mhaith leat an sciar cianda {name} ó {owner}@{remote} a chur leis?",
     "Remote share password" : "Pasfhocal comhroinnte cianda",
-    "Incoming share could not be processed" : "Níorbh fhéidir an sciar isteach a phróiseáil",
-    "Clipboard is not available" : "Níl fáil ar an ngearrthaisce",
-    "Your Federated Cloud ID:" : "D'aitheantas scamall Cónaidhme:",
-    "Twitter" : "Twitter",
-    "Diaspora" : "Diaspóra"
+    "Incoming share could not be processed" : "Níorbh fhéidir an sciar isteach a phróiseáil"
 },
 "nplurals=5; plural=(n==1 ? 0 : n==2 ? 1 : n<7 ? 2 : n<11 ? 3 : 4);");
