@@ -23,6 +23,16 @@ OC.L10N.register(
     "Sharing" : "Dela",
     "Federated file sharing" : "Federerad fildelning",
     "Provide federated file sharing across servers" : "Erbjuder federerad fildelning mellan servrar",
+    "Confirm data upload to lookup server" : "Bekräfta datauppladdning till uppslagningstjänst",
+    "When enabled, all account properties (e.g. email address) with scope visibility set to \"published\", will be automatically synced and transmitted to an external system and made available in a public, global address book." : "När detta är aktiverat kommer alla kontouppgifter (t.ex. e-postadress) med synlighetsomfång inställt på “publicerad” automatiskt att synkroniseras och överföras till ett externt system och göras tillgängliga i en offentlig, global adressbok.",
+    "Disable upload" : "Inaktivera uppladdning",
+    "Enable data upload" : "Aktivera datauppladdning",
+    "Confirm querying lookup server" : "Bekräfta förfrågan till uppslagningstjänst",
+    "When enabled, the search input when creating shares will be sent to an external system that provides a public and global address book." : "När detta är aktiverat kommer sökinmatningen vid skapande av delningar att skickas till ett externt system som tillhandahåller en offentlig och global adressbok.",
+    "This is used to retrieve the federated cloud ID to make federated sharing easier." : "Detta används för att hämta federerat moln-ID för att göra federerad delning enklare.",
+    "Moreover, email addresses of users might be sent to that system in order to verify them." : "Dessutom kan användares e-postadresser skickas till systemet för att verifieras.",
+    "Disable querying" : "Inaktivera förfrågningar",
+    "Enable querying" : "Aktivera förfrågningar",
     "Unable to update federated files sharing config" : "Kunde inte uppdatera konfigurationen för federerad fildelning",
     "Adjust how people can share between servers. This includes shares between people on this server as well if they are using federated sharing." : "Anpassa hur användare kan dela mellan servrar. Detta inkluderar även delningar mellan användare på denna server ifall de använder federerad delning.",
     "Allow people on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Tillåt användare på denna server att skicka delningar till andra servrar (denna inställning ger också WebDAV-tillgång till offentliga delningar)",
@@ -36,6 +46,7 @@ OC.L10N.register(
     "Automatically accept shares from trusted federated accounts and groups by default" : "Acceptera automatiskt delningar från betrodda federerade konton och grupper som standard",
     "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "Dela med mig genom mitt #Nextcloud federerade moln-ID, se {url}",
     "Share with me through my #Nextcloud Federated Cloud ID" : "Dela med mig genom mitt #Nextcloud federerade moln-ID",
+    "Share with me via Nextcloud" : "Dela med mig via Nextcloud",
     "Cloud ID copied to the clipboard" : "Moln-ID kopierades till urklippet",
     "Copy to clipboard" : "Kopiera till urklipp",
     "Clipboard not available. Please copy the cloud ID manually." : "Urklipp är inte tillgängligt. Kopiera moln-ID manuellt.",
@@ -49,17 +60,12 @@ OC.L10N.register(
     "formerly Twitter" : "tidigare Twitter",
     "Mastodon" : "Mastodon",
     "Add to your website" : "Lägg till på din hemsida",
-    "Share with me via Nextcloud" : "Dela med mig via Nextcloud",
     "HTML Code:" : "HTML Kod:",
     "Cancel" : "Avbryt",
     "Add remote share" : "Lägg till extern delning",
     "Remote share" : "Extern delning",
     "Do you want to add the remote share {name} from {owner}@{remote}?" : "Vill du lägga till extern delning {name} från {owner}@{remote}?",
     "Remote share password" : "Lösenord för extern delning",
-    "Incoming share could not be processed" : "Inkommande delning kunde inte behandlas",
-    "Clipboard is not available" : "Urklipp är inte tillgängligt",
-    "Your Federated Cloud ID:" : "Ditt federerade moln-ID:",
-    "Twitter" : "Twitter",
-    "Diaspora" : "Diaspora"
+    "Incoming share could not be processed" : "Inkommande delning kunde inte behandlas"
 },
 "nplurals=2; plural=(n != 1);");
