@@ -106,6 +106,7 @@ OC.L10N.register(
     "Unknown date" : "Dáta anaithnid",
     "Clear filter" : "Glan an scagaire",
     "Modified" : "Athraithe",
+    "Search everywhere" : "Cuardaigh i ngach áit",
     "Type" : "Cineál",
     "Active filters" : "Scagairí gníomhacha",
     "Remove filter" : "Bain an scagaire",
@@ -124,7 +125,11 @@ OC.L10N.register(
     "Column headers with buttons are sortable." : "Is féidir ceanntásca colún le cnaipí a shórtáil.",
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Níl an liosta seo le fáil go hiomlán ar chúiseanna feidhmíochta. Déanfar na comhaid a rindreáil agus tú ag dul tríd an liosta.",
     "File not found" : "Comhad gan aimsiú",
-    "{count} selected" : "{count} roghnaithe",
+    "_{count} selected_::_{count} selected_" : ["{count} roghnaithe","{count} roghnaithe","{count} roghnaithe","{count} roghnaithe","{count} roghnaithe"],
+    "Search globally by filename …" : "Cuardaigh go domhanda de réir ainm comhaid …",
+    "Search here by filename …" : "Cuardaigh anseo de réir ainm comhaid …",
+    "Search scope options" : "Roghanna raon feidhme cuardaigh",
+    "Search globally" : "Cuardaigh go domhanda",
     "{usedQuotaByte} used" : "{usedQuotaByte} úsáidte",
     "{used} of {quota} used" : "{used} de {quota} in úsáid",
     "{relative}% used" : "{relative}% in úsáid",
@@ -179,21 +184,24 @@ OC.L10N.register(
     "No files in here" : "Níl aon chomhaid istigh anseo",
     "Upload some content or sync with your devices!" : "Uaslódáil roinnt inneachair nó sioncronaigh le do ghléasanna!",
     "Go back" : "Dul ar ais",
-    "Filter file names …" : "Scag ainmneacha na gcomhad…",
     "Views" : "Radhairc",
     "Files settings" : "Socruithe comhaid",
     "Your files" : "Do chuid comhad",
     "Open in files" : "Oscail i gcomhaid",
     "File cannot be accessed" : "Ní féidir an comhad a rochtain",
     "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Níorbh fhéidir an comhad a aimsiú nó níl cead agat féachaint air. Iarr ar an seoltóir é a roinnt.",
+    "No search results for “{query}”" : "Gan aon torthaí cuardaigh le haghaidh ”{query}”",
+    "Search for files" : "Cuardaigh comhaid",
     "Clipboard is not available" : "Níl fáil ar an ngearrthaisce",
     "WebDAV URL copied to clipboard" : "URL WebDAV cóipeáilte chuig an ngearrthaisce",
+    "Default view" : "Amharc réamhshocraithe",
+    "All files" : "Gach comhad",
+    "Personal files" : "Comhaid phearsanta",
     "Sort favorites first" : "Sórtáil na cinn is ansa leat ar dtús",
     "Sort folders before files" : "Sórtáil fillteáin roimh chomhaid",
     "Show hidden files" : "Taispeáin comhaid i bhfolach",
     "Show file type column" : "Taispeáin colún cineál comhaid",
     "Crop image previews" : "Réamhamhairc íomhá barr",
-    "Enable the grid view" : "Cumasaigh an radharc greille",
     "Enable folder tree" : "Cumasaigh crann fillteáin",
     "Additional settings" : "Socruithe breise",
     "WebDAV" : "WebDAV",
@@ -228,6 +236,7 @@ OC.L10N.register(
     "Show those shortcuts" : "Taispeáin na haicearraí sin",
     "You" : "tú",
     "Shared multiple times with different people" : "Roinnte go minic le daoine éagsúla",
+    "Unable to change the favorite state of the file" : "Ní féidir staid an chomhaid is fearr leat a athrú",
     "Error while loading the file data" : "Earráid agus sonraí an chomhaid á lódáil",
     "Owner" : "Úinéir",
     "Remove from favorites" : "Bain ó cheanáin",
@@ -268,8 +277,11 @@ OC.L10N.register(
     "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Tá tú ar tí {count} mír a scriosadh","Tá tú ar tí {count} mír a scriosadh","Tá tú ar tí {count} mír a scriosadh","Tá tú ar tí {count} mír a scriosadh","Tá tú ar tí {count} mír a scriosadh"],
     "Confirm deletion" : "Deimhnigh scriosadh",
     "Cancel" : "Cealaigh",
+    "Download" : "Íoslódáil",
     "Moving \"{source}\" to \"{destination}\" …" : "Ag bogadh \"{source}\" go \"{destination}\" ...",
     "Copying \"{source}\" to \"{destination}\" …" : "“{source}” á chóipeáil go “{destination}”…",
+    "Destination is not a folder" : "Ní fillteán é ceann scríbe",
+    "This file/folder is already in that directory" : "Tá an comhad/fillteán seo san eolaire sin cheana féin",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "Ní féidir leat comhad/fillteán a bhogadh isteach ann féin nó isteach i bhfofhillteán de féin",
     "(copy)" : "(cóip)",
     "(copy %n)" : "(cóip %n)",
@@ -331,6 +343,9 @@ OC.L10N.register(
     "Files moved successfully" : "Bogadh na comhaid go rathúil",
     "Conflicts resolution skipped" : "Léiríodh réiteach coinbhleachta",
     "Upload cancelled" : "Cuireadh an t-uaslódáil ar ceal",
+    "Could not rename \"{oldName}\", it does not exist any more" : "Níorbh fhéidir \"{oldName}\" a athainmniú, níl sé ann a thuilleadh",
+    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Tá an t-ainm \"{newName}\" in úsáid cheana féin san fhillteán \"{dir}\". Roghnaigh ainm eile le do thoil.",
+    "Could not rename \"{oldName}\"" : "Níorbh fhéidir \"{oldName}\" a athainmniú",
     "This operation is forbidden" : "Tá an oibríocht seo toirmiscthe",
     "This directory is unavailable, please check the logs or contact the administrator" : "Níl an t-eolaire seo ar fáil, seiceáil na logaí nó déan teagmháil leis an riarthóir le do thoil",
     "Storage is temporarily not available" : "Níl stóráil ar fáil go sealadach",
@@ -346,10 +361,8 @@ OC.L10N.register(
     "List of favorite files and folders." : "Liosta de na comhaid agus na fillteáin is fearr leat.",
     "No favorites yet" : "Níl aon cheanáin go fóill",
     "Files and folders you mark as favorite will show up here" : "Taispeánfar comhaid agus fillteáin a mharcálann tú mar is fearr leat anseo",
-    "All files" : "Gach comhad",
     "List of your files and folders." : "Liosta de do chuid comhad agus fillteáin.",
     "All folders" : "Gach fillteáin",
-    "Personal files" : "Comhaid phearsanta",
     "List of your files and folders that are not shared." : "Liosta de do chuid comhad agus fillteáin nach bhfuil roinnte.",
     "No personal files found" : "Níor aimsíodh aon chomhaid phearsanta",
     "Files that are not shared will show up here." : "Taispeánfar comhaid nach bhfuil roinnte anseo.",
@@ -357,12 +370,13 @@ OC.L10N.register(
     "List of recently modified files and folders." : "Liosta de chomhaid agus de fhillteáin a athraíodh le déanaí.",
     "No recently modified files" : "Níl aon chomhaid athraithe le déanaí",
     "Files and folders you recently modified will show up here." : "Taispeánfar comhaid agus fillteáin a d'athraigh tú le déanaí anseo.",
+    "Search" : "Cuardach",
+    "Search results within your files." : "Torthaí cuardaigh laistigh de do chuid comhad.",
     "No entries found in this folder" : "Níor aimsíodh aon iontrálacha san fhillteán seo",
     "Select all" : "Roghnú go léir",
     "Upload too large" : "Íoslódáil ró-mhór",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Sáraíonn na comhaid atá tú ag iarraidh a uaslódáil an t-uasmhéid le haghaidh uaslódáil comhad ar an bhfreastalaí seo.",
     "File could not be found" : "Níorbh fhéidir an comhad a aimsiú",
-    "Download" : "Íoslódáil",
     "Show list view" : "Taispeáin amharc liosta",
     "Show grid view" : "Taispeáin radharc greille",
     "Close" : "Dún",
@@ -401,9 +415,6 @@ OC.L10N.register(
     "Copied {origin} inside {destination}" : "Cóipeáladh {origin} taobh istigh de {destination}",
     "Copied {origin} and {nbfiles} other files inside {destination}" : "Cóipeáladh {origin} agus {nbfiles} comhaid eile laistigh de {destination}",
     "{newName} already exists" : "Tá {newName} ann cheana",
-    "Could not rename \"{fileName}\", it does not exist any more" : "Níorbh fhéidir \"{fileName}\" a athainmniú, níl sé ann a thuilleadh",
-    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Tá an t-ainm \"{targetName}\" in úsáid cheana féin san fhillteán \"{dir}\". Roghnaigh ainm eile le do thoil.",
-    "Could not rename \"{fileName}\"" : "Níorbh fhéidir \"{fileName}\" a athainmniú",
     "Could not create file \"{file}\"" : "Níorbh fhéidir comhad \"{file}\" a chruthú",
     "Could not create file \"{file}\" because it already exists" : "Níorbh fhéidir an comhad \"{file}\" a chruthú toisc go bhfuil sé ann cheana",
     "Could not create folder \"{dir}\" because it already exists" : "Níorbh fhéidir fillteán \"{dir}\" a chruthú toisc go bhfuil sé ann cheana",
@@ -445,6 +456,7 @@ OC.L10N.register(
     "Upload (max. %s)" : "Uaslódáil (%s ar a mhéad)",
     "Submitting fields…" : "Réimsí á gcur isteach…",
     "Filter filenames…" : "Scag ainmneacha comhaid…",
+    "Enable the grid view" : "Cumasaigh an radharc greille",
     "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} fillteán","{folderCount} fillteáin","{folderCount} fillteáin","{folderCount} fillteáin","{folderCount} fillteáin"],
     "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} comhad","{fileCount} comhaid","{fileCount} comhaid","{fileCount} comhaid","{fileCount} comhaid"],
     "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 chomhad agus {folderCount} fillteán","1 chomhad agus {folderCount} fillteáin","1 chomhad agus {folderCount} fillteáin","1 chomhad agus {folderCount} fillteáin","1 chomhad agus {folderCount} fillteáin"],
@@ -456,7 +468,6 @@ OC.L10N.register(
     "%1$s (renamed)" : "%1$s (athainmnithe)",
     "renamed file" : "comhad athainmnithe",
     "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Tar éis na hainmneacha comhad atá comhoiriúnach le Windows a chumasú, ní féidir comhaid atá ann cheana a mhodhnú a thuilleadh ach is féidir lena n-úinéir iad a athainmniú go hainmneacha nua bailí.",
-    "{count} files could not be converted" : "{count} níorbh fhéidir comhaid a thiontú",
-    "{count} files successfully converted" : "{count} comhaid a thiontú go rathúil"
+    "Filter file names …" : "Scag ainmneacha na gcomhad…"
 },
 "nplurals=5; plural=(n==1 ? 0 : n==2 ? 1 : n<7 ? 2 : n<11 ? 3 : 4);");
