@@ -52,15 +52,17 @@ OC.L10N.register(
     "No picture for this day" : "這天沒有照片",
     "Picture taken on this day will show up here." : "這天拍攝的照片將會顯示在此處。",
     "More photos from this day" : "更多這天的照片",
+    "_%n photos_::_%n photos_" : ["%n 個照片"],
     "_%n unassigned photo_::_%n unassigned photos_" : ["%n 個未指派的照片"],
     "Favorite" : "收藏",
     "Favorite image, open the full size \"{name}\" image" : "收藏影像，開啟「{name}」的原始尺寸影像",
     "Open the full size \"{name}\" image" : "開啟「{name}」的原始尺寸影像",
     "Select image {imageName}" : "選取圖片 {imageName}",
     "Open the \"{name}\" folder" : "開啟「{name}」資料夾",
-    "Back to {folder}" : "回到 {folder}",
     "Go back" : "返回",
-    "Share this folder" : "分享此資料夾",
+    "Date range" : "日期範圍",
+    "Select a date range" : "選取日期範圍",
+    "Select places" : "選取地點",
     "Dates" : "日曆",
     "Jump to specific date in list" : "跳到清單中的指定日期",
     "Jump to {date}" : "跳到 {date}",
@@ -86,6 +88,7 @@ OC.L10N.register(
     "Choose the folder where photos and albums are uploaded to." : "選擇照片與相簿上傳到的資料夾。",
     "_%n photo_::_%n photos_" : ["%n 張照片"],
     "Unselect all" : "取消全選",
+    "Toggle filter" : "切換篩選器",
     "Add photos to this album" : "新增照片至此相簿",
     "Manage collaborators for this album" : "管理此相簿的協作者",
     "Open actions menu" : "開啟動作選單",
@@ -129,15 +132,16 @@ OC.L10N.register(
     "Photos with tags will show up here" : "此處會顯示圖片的標籤",
     "Popular tags" : "熱門標籤",
     "All tags" : "全部標籤",
+    "Create new album from filters" : "從篩選條件建立新相簿",
     "One of the source folders does not exist" : "其中一個來源資料夾不存在",
     "Add to album" : "新增至相簿",
     "Delete selection" : "刪除選擇",
     "No photos or videos in here" : "此處沒有照片或影片",
     "Unassigned faces" : "未指派的臉孔",
-    "_%n photos_::_%n photos_" : ["%n 個照片"],
     "Failed to fetch collection." : "擷取收藏品失敗。",
     "Failed to fetch collections list." : "擷取收藏清單失敗。",
     "Failed to fetch faces list." : "擷取臉部清單失敗。",
+    "Error fetching files" : "擷取檔案時發生錯誤",
     "All your media" : "您所有的媒體",
     "Album {title}" : "相簿 {title}",
     "Shared Albums" : "已分享的相簿",
@@ -148,6 +152,14 @@ OC.L10N.register(
     "{title}'s face" : "{title} 的臉",
     "{startDate} to {endDate}" : "{startDate} 到 {endDate}",
     "Details" : "詳細資訊",
+    "Failed to add {fileBaseName} to collection {collectionFileName}" : "無法將 {fileBaseName} 新增至收藏 {collectionFileName}",
+    "Failed to delete {fileBaseName}" : "刪除 {fileBaseName} 失敗",
+    "Failed to create {collectionFileName}" : "建立 {collectionFileName} 失敗",
+    "Failed to rename {currentCollectionFileName} to {newCollectionFileName}" : "無法將 {currentCollectionFileName} 重新命名為 {newCollectionFileName}",
+    "Failed to update properties of {collectionFileName} with {properties}" : "無法使用 {properties} 更新 {collectionFileName} 的屬性",
+    "Failed to delete {collectionFileName}" : "刪除 {collectionFileName} 失敗",
+    "Failed to move {fileBaseName} to person {faceName}" : "將 {fileBaseName} 移動到人物 {faceName} 失敗",
+    "Failed to remove {fileBaseName}" : "移除 {fileBaseName} 失敗",
     "Failed to rename {oldName} to {faceName}" : "無法將 {oldName} 重新命名為 {faceName}",
     "Failed to delete {faceName}" : "刪除 {faceName} 失敗",
     "Failed to delete {fileId}" : "刪除 {fileId} 失敗",
@@ -155,6 +167,8 @@ OC.L10N.register(
     "Failed to set favorite state for {fileId}" : "無法設定 {fileId} 的收藏狀態",
     "Failed to set favorite state for {fileName}" : "無法設定 {fileName} 的收藏狀態",
     "Could not load photos folder" : "無法載入照片資料夾",
+    "Back to {folder}" : "回到 {folder}",
+    "Share this folder" : "分享此資料夾",
     "One of the source folders does not exists" : "其中一個來源資料夾不存在",
     "Add" : "新增"
 },
