@@ -137,20 +137,20 @@ OC.L10N.register(
     "Actions" : "Agoj",
     "Results from other categories" : "Rezultoj el aliaj kategorioj",
     "No apps found for your version" : "Neniu aplikaĵo trovita por via versio",
+    "Group name" : "Gruponomo",
     "Loading" : "Ŝargado",
     "Type" : "Tipo",
     "Learn more" : "Scii pli",
     "Confirm" : "Konfirmi",
     "Cancel" : "Nuligi",
     "Description" : "Priskribo",
-    "View in store" : "Vidi en butiko",
+    "View in store" : "Vidi en la aplikaĵejo",
     "Visit website" : "Viziti retejon",
     "Admin documentation" : "Dokumentaro por administranto",
     "Developer documentation" : "Dokumentaro por programisto",
     "Details" : "Detaloj",
-    "All" : "Ĉio",
+    "All" : "Ĉiuj",
     "Limit app usage to groups" : "Limigi aplikaĵan uzon al grupoj",
-    "No results" : "Neniu rezulto",
     "Update to {version}" : "Ĝisdatigi al {version}",
     "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Tiu aplikaĵo ne postulas minimuman Nextcloud-version. Tio estos eraro en la estonteco.",
     "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Tiu aplikaĵo ne postulas maksimuman Nextcloud-version. Tio estos eraro en la estonteco.",
@@ -164,6 +164,7 @@ OC.L10N.register(
     "Rate" : "Pritakso",
     "Changelog" : "Ŝanĝoprotokolo",
     "Google Chrome for Android" : "Google Chrome por Android",
+    "{productName} Android app" : "Android-aplikaĵo {productName}",
     "This session" : "Tiu ĉi seanco",
     "Marked for remote wipe" : "Elektita por fora forviŝado",
     "Device settings" : "Aparataj agordoj",
@@ -176,13 +177,14 @@ OC.L10N.register(
     "Devices & sessions" : "Aparatoj kaj seancoj",
     "Web, desktop and mobile clients currently logged in to your account." : "Reta, surtabla kaj portebla klientoj nun konektitaj al via konto.",
     "Error while creating device token" : "Eraro dum kreo de aparata ĵetono",
-    "App name" : "Aplikaĵa nomo",
+    "App name" : "Aplijaĵa nomo",
     "Create new app password" : "Krei novan aplikaĵan pasvorton",
     "Could not copy app password. Please copy it manually." : "Ne eblis kopii la aplikaĵan pasvorton. Bv. kopii ĝin permane.",
     "Login" : "Ensaluti",
     "Password" : "Pasvorto",
     "Show QR code for mobile apps" : "Montri rapidrespondan (QR) kodon por porteblaj aplikaĵoj",
     "Use system cron service to call the cron.php file every 5 minutes." : "Uzu la sisteman „cron“-servon por voki cron.php ĉiujn 5 minutojn.",
+    "Password confirmation is required" : "Konfirmo per pasvorto estas bezonata",
     "Server-side encryption" : "Ĉeservila ĉifrado",
     "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "Ĉeservila ĉifrado elbigas ĉifri ĉiujn alŝutitajn dosierojn al la servilo. Tio havas kelkajn limigojn kiel pli malbonan rendimenton, do ŝaltu tion nur se necese.",
     "Enable server-side encryption" : "Ŝalti ĉeservilan ĉifradon",
@@ -195,19 +197,16 @@ OC.L10N.register(
     "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Ĉiam estas bone krei savkopiojn de viaj datumoj. Se tiuj ĉi lastaj estas ĉifritaj, certigu, ke vi savkopias ankaŭ la ĉifroŝlosilon kune kun la datumoj.",
     "This is the final warning: Do you really want to enable encryption?" : "Jen la fina averto: ĉu vi certe volas ŝalti ĉifradon?",
     "Submit" : "Sendi",
-    "Remove group" : "Forigi grupon",
     "Current password" : "Nuna pasvorto",
     "New password" : "Nova pasvorto",
-    "Change password" : "Ŝanĝi la pasvorton",
     "Picture provided by original account" : "Bildo el la origina konto",
     "You are a member of the following groups:" : "Vi estas membro el la jenaj grupoj:",
     "No email address set" : "Neniu retpoŝta adreso agordita",
     "Languages" : "Lingvoj",
     "Help translate" : "Helpu traduki",
     "No language set" : "Neniu lingvo agordita",
+    "Week starts on {firstDayOfWeek}" : "Semajno komencas je {firstDayOfWeek}",
     "Your phone number" : "Via telefonnumero",
-    "Add" : "Aldoni",
-    "Create" : "Krei",
     "Change" : "Ŝanĝi",
     "Delete" : "Forigi",
     "Default language" : "Defaŭlta lingvo",
@@ -240,7 +239,6 @@ OC.L10N.register(
     "Select default quota" : "Elekti defaŭltan kvoton",
     "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Kiel administranto, vi povas agordi plidetale la kunhavigon. Bv. vidi la dokumentaron pri tio.",
     "Admins" : "Administrantoj",
-    "Group name" : "Gruponomo",
     "Sending…" : "Sendado...",
     "Email sent" : "La retpoŝtaĵo sendiĝis",
     "Location" : "Loko",
@@ -301,10 +299,6 @@ OC.L10N.register(
     "Subscribe to our newsletter" : "Aboni nian retan bultenon",
     "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Tiu elkomunuma eldono de Nextcloud ne estas subtenata, kaj tuj-sciigoj ne disponeblas.",
     "Use a second factor besides your password to increase security for your account." : "Uzu duan fazon krom via pasvorto por plisekurigi vian konton.",
-    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "Mankas kelkaj indeksoj en la datumbazo. Pro la ebla malrapideco aldoni indeksojn en grandaj tabeloj, ili ne estis aldonitaj aŭtomate. Vi povas aldoni ilin mane, rulante komandlinie „occ db:add-missing-indices“, dum la servilo estas funkcianta. Kiam la indeksoj ekzistos, la uzo de tiuj tabelojn estos kutime pli rapida.",
-    "New user" : "Nova uzanto",
-    "Username" : "Uzantonomo",
-    "User backend" : "Uzanto-loko",
-    "Follow us on Twitter" : "Sekvu nin per Twitter"
+    "You are using <strong>{usage}</strong>" : "Vi uzas <strong>{usage}</strong>"
 },
 "nplurals=2; plural=(n != 1);");
