@@ -228,10 +228,9 @@ OC.L10N.register(
     "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Uvijek je dobra ideja redovito izrađivati sigurnosne kopije podataka; ako upotrebljavate šifriranje, obavezno sigurnosno kopirajte ključeve za šifriranje zajedno sa svojim podacima.",
     "This is the final warning: Do you really want to enable encryption?" : "Ovo je posljednje upozorenje: želite li zaista omogućiti šifriranje?",
     "Submit" : "Šalji",
-    "Remove group" : "Ukloni grupu",
     "Current password" : "Trenutna zaporka",
     "New password" : "Nova zaporka",
-    "Change password" : "Promijeni zaporku",
+    "Change password" : "Promijeni lozinku",
     "Picture provided by original account" : "Slika s izvornog računa",
     "You are a member of the following groups:" : "Član ste sljedećih grupa:",
     "Your full name" : "Vaše ime i prezime",
@@ -253,13 +252,15 @@ OC.L10N.register(
     "Unable to update language" : "Nije moguće ažurirati jezik",
     "Help translate" : "Pomozite prevesti",
     "No language set" : "Nije postavljen jezik",
+    "Week starts on {firstDayOfWeek}" : "Tjedan počinje {firstDayOfWeek}",
     "Your organisation" : "Vaša organizacija",
-    "Your phone number" : "Vaš broj telefona",
     "Edit your Profile visibility" : "Uredite vidljivost profila",
     "Unable to update profile enabled state" : "Nije moguće ažurirati stanje omogućenog profila",
     "The more restrictive setting of either visibility or scope is respected on your Profile. For example, if visibility is set to \"Show to everyone\" and scope is set to \"Private\", \"Private\" is respected." : "Na profilu se primjenjuje stroža postavka vidljivosti ili opsega. Na primjer, ako je vidljivost postavljena na „Prikaži svima”, a opseg je postavljen na „Privatno”, primjenjuje se „Privatno”.",
     "Unable to update visibility of {displayId}" : "Nije moguće ažurirati vidljivost za {displayId}",
     "Your role" : "Vaša uloga",
+    "Unable to update federation scope of the primary {property}" : "Nije moguće ažurirati opseg udruženja primarnog {property}",
+    "Unable to update federation scope of additional {property}" : "Nije moguće ažurirati opseg udruženja dodatnog {property}",
     "Add" : "Dodaj",
     "Create" : "Stvori",
     "Change" : "Promijeni",
@@ -270,7 +271,6 @@ OC.L10N.register(
     "Other languages" : "Drugi jezici",
     "Password change is disabled because the master key is disabled" : "Onemogućeno je mijenjanje zaporke jer je onemogućen glavni ključ",
     "New account" : "Novi račun",
-    "Display name" : "Ime za prikaz",
     "Email" : "E-pošta",
     "Quota" : "Kvota",
     "Language" : "Jezik",
@@ -289,7 +289,6 @@ OC.L10N.register(
     "Account deletion" : "Brisanje računa",
     "Delete {userid}'s account" : "Izbriši račun koji pripada {userid}",
     "Welcome mail sent!" : "Poslana poruka dobrodošlice!",
-    "Done" : "Gotovo",
     "Edit" : "Uredi",
     "Show storage path" : "Prikaži put pohrane",
     "Show last login" : "Prikaži posljednju prijavu",
@@ -383,16 +382,8 @@ OC.L10N.register(
     "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Ovo izdanje Nextclouda nije podržano i nisu dostupne trenutne obavijesti.",
     "Use a second factor besides your password to increase security for your account." : "Koristite se i drugim faktorom pored zaporke kako biste povećali sigurnost svog računa.",
     "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Ako se za povezivanje s Nextcloudom koristite aplikacijama treće strane, stvorite i konfigurirajte lozinku za svaku aplikaciju prije omogućavanja drugog faktora za provođenje autentifikacije.",
-    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "U bazi podataka nedostaju određeni indeksi. Zbog činjenice da bi dodavanje indeksa u velikim tablicama moglo potrajati neko duže vrijeme, isti se ne dodaju automatski. Izvršenjem „occ db:add-missing-indices” se ti indeksi mogu ručno dodati dok instanca radi. Kada se indeksi dodaju, upiti u te tablice obično su mnogo brži.",
     "Set default expiration date for shares" : "Postavi zadani datum isteka dijeljenja",
     "Your biography" : "Vaša biografija",
-    "New user" : "Novi korisnik",
-    "_{userCount} user_::_{userCount} users_" : ["{userCount} korisnik","{userCount} korisnika","{userCount} korisnika"],
-    "Username" : "Korisničko ime",
-    "User backend" : "Korisnički pozadinski sustav",
-    "Add user to group" : "Dodaj korisnika u grupu",
-    "Server error while trying to add WebAuthn device" : "Pogreška poslužitelja pri dodavanju WebAuthn uređaja",
-    "Name your device" : "Dodijelite naziv svom uređaju",
-    "Follow us on Twitter" : "Pratite nas na Twitteru"
+    "You are using <strong>{usage}</strong>" : "Koristite <strong>{usage}</strong>"
 },
 "nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
