@@ -180,6 +180,7 @@ OC.L10N.register(
     "No apps found for your version" : "За вашата верзија не се пронајдени апликации",
     "_%n app has an update available_::_%n apps have an update available_" : ["За %n апликација има достапно ажурирање","За %n апликации има достапно ажурирање"],
     "_Update_::_Update all_" : ["Ажурирај","Ажурирај ги сите"],
+    "Group name" : "Име на група",
     "Type" : "Вид",
     "Learn more" : "Научи повеќе",
     "Confirm" : "Потврди",
@@ -256,10 +257,9 @@ OC.L10N.register(
     "This is the final warning: Do you really want to enable encryption?" : "Ова е последно предупредување: Дали навистина сакате да овозможите енкрипција?",
     "Submit" : "Испрати",
     "Rename group" : "Преименувај група",
-    "Remove group" : "Отстрани група",
     "Current password" : "Моментална лозинка",
     "New password" : "Нова лозинка",
-    "Change password" : "Промени лозинка",
+    "Change password" : "Смени лозинка",
     "Choose your profile picture" : "Избери за фотографија за профилот",
     "Please select a valid png or jpg file" : "Изберете png или jpg датотека",
     "Error setting profile picture" : "Грешка при поставување на фотографија за профилот",
@@ -275,6 +275,8 @@ OC.L10N.register(
     "Set as profile picture" : "Постави фотографија на профилот",
     "Please note that it can take up to 24 hours for your profile picture to be updated everywhere." : "Имајте предвид дека може да потрае до 24 часа за да се ажурира аватарот насекаде.",
     "Enter your date of birth" : "Внесете го вашиот датум на раѓање",
+    "You are using {s}{usage}{/s}" : "Користите {s}{usage}{/s}",
+    "You are using {s}{usage}{/s} of {s}{totalSpace}{/s} ({s}{usageRelative}%{/s})" : "Користите {s}{usage}{/s} of {s}{totalSpace}{/s} ({s}{usageRelative}%{/s})",
     "You are a member of the following groups:" : "Член сте на следниве групи",
     "Your full name" : "Вашето целосно име",
     "Email options" : "Е-пошта параметри",
@@ -304,6 +306,7 @@ OC.L10N.register(
     "Your phone number" : "Вашиот телефонски број",
     "Edit your Profile visibility" : "Уредете ја видливоста на вашиот профил",
     "Unable to update profile enabled state" : "Неможе да се ажурира достапноста на профилот",
+    "Enable profile" : "Овозможи профил",
     "The more restrictive setting of either visibility or scope is respected on your Profile. For example, if visibility is set to \"Show to everyone\" and scope is set to \"Private\", \"Private\" is respected." : "Порестриктивни параметри за видливост или опсег се почитува на вашиот профил. На пример, ако видливоста е поставена на \"Прикажи на сите\", а опсегот е поставен на \"Приватно\", се почитува \"Приватно\".",
     "Unable to update visibility of {displayId}" : "Неможе да се ажурира видливоста на {displayId}",
     "Your role" : "Ваша улога",
@@ -333,12 +336,16 @@ OC.L10N.register(
     "Quota" : "Квота",
     "Language" : "Јазик",
     "Set default language" : "Постави стандарден јазик",
+    "_{userCount} account …_::_{userCount} accounts …_" : ["{userCount} сметка …","{userCount} сметки …"],
+    "_{userCount} account_::_{userCount} accounts_" : ["{userCount} сметка","{userCount} сметки"],
     "Total rows summary" : "Резиме на вкупно редови",
     "Scroll to load more rows" : "Одете надолу за да се вчитаат повеќе редови",
     "Password or insufficient permissions message" : "Порака за лозинка или недоволна дозвола",
     "Avatar" : "Аватар",
+    "Account name" : "Корисничко име",
     "Group admin for" : "Администратор на група",
     "Storage location" : "Локација на складиште",
+    "First login" : "Прво најавување",
     "Last login" : "Последно најавување",
     "{size} used" : "искористено {size}",
     "Delete account" : "Избриши сметка",
@@ -354,6 +361,7 @@ OC.L10N.register(
     "Set the language" : "Постави јазик",
     "Done" : "Готово",
     "Edit" : "Уреди",
+    "Account management settings" : "Параметри за кориснички менаџмент",
     "Visibility" : "Видливост",
     "Show language" : "Прикажи јазик",
     "Show storage path" : "Прикажи патека на складиште",
@@ -375,8 +383,8 @@ OC.L10N.register(
     "Your browser does not support WebAuthn." : "Вашиот прелистувач не поддржува WebAuthn.",
     "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Како администратор, можете детално да го прилагодите однесувањето на споделувањето. Погледнете ја документацијата за повеќе информации.",
     "You need to enable the File sharing App." : "Треба да ја овозможите апликацијата Споделување на датотеки.",
+    "All accounts" : "Сите сметки",
     "Admins" : "Администратори",
-    "Group name" : "Име на група",
     "Sending…" : "Испраќа…",
     "Email sent" : "Е-порака пратена",
     "Location" : "Локација",
@@ -456,36 +464,9 @@ OC.L10N.register(
     "Subscribe to our newsletter" : "Претплатете се на нашиот билтен",
     "Use a second factor besides your password to increase security for your account." : "Користете втор фактор и покрај вашата лозинка за да ја зголемите безбедноста на вашата сметка.",
     "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Доколку користите друга апликација за поврзување на Nextcloud, осигурајте се дека имате креирано лозинка за секоја апликација пред да овозможите втор фактор.",
-    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "Во базата недостасуваат некој индекси. Поради фактот што додавањето индекси во големи бази може да потрае, тие не беа додадени автоматски. Со стартување на командата \"occ db:add-missing-indices\" ќе бидат додадени оние индекси што недостасуваат и инстанцата непречено ќе работи. Еднаш кога ќе бидат додадени индексите, барањата во табелите ќе биде многу побрзо.",
-    "MariaDB version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MariaDB 10.2 or higher." : "Се користи MariaDB верзија\"%s\". Nextcloud 21 и поголемите верзии, повеќе нема да ја поддржува оваа верзија и потебно е да ја ажурирате на верзија 10.2 или понова.",
-    "MySQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MySQL 8.0 or MariaDB 10.2 or higher." : "Се користи MySQL верзија\"%s\". Nextcloud 21 и поголемите верзии, повеќе нема да ја поддржува оваа верзија и потебно е да ја ажурирате на верзија 8.0 или MariaDB 10.2 или понова.",
-    "PostgreSQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require PostgreSQL 9.6 or higher." : "Се користи PostgreSQL верзија\"%s\". Nextcloud 21 и поголемите верзии, повеќе нема да ја поддржува оваа верзија и потебно е да ја ажурирате на верзија 9.6 или понова.",
-    "Speech-To-Text" : "Говор-во-текст",
-    "Speech-To-Text can be implemented by different apps. Here you can set which app should be used." : "Говор-во-текст може да се имплементира од различни апликации. Овде можете да поставите која апликација треба да се користи.",
-    "None of your currently installed apps provide Speech-To-Text functionality" : "Ниту една од вашите тековно инсталирани апликации не обезбедува функционалност за говор во текст",
-    "None of your currently installed apps provide Text processing functionality" : "Ниту една од вашите моментално инсталирани апликации не обезбедува функционалност за обработка на текст",
     "Set default expiration date for shares" : "Постави основен рок на траење за споделувањата",
     "Your biography" : "Ваша биографија",
     "You are using <strong>{usage}</strong>" : "Користите <strong>{usage}</strong>",
-    "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "Користите <strong>{usage}</strong> од <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)",
-    "Set user manager" : "Постави корисник за менаџер",
-    "Username will be autogenerated" : "Корисничкото име ќе биде автоматски генерирано",
-    "Username (required)" : "Корисничко име (задолжително)",
-    "New user" : "Нов корисник",
-    "Groups (required)" : "Групи (задолжително)",
-    "Set user groups" : "Постави корисничка група",
-    "Administered groups" : "Администрирани групи",
-    "Set user as admin for …" : "Назначи го корисникот како администратор за ...",
-    "Set user quota" : "Постави квота за корисник",
-    "Add new user" : "Додади нов корисник",
-    "_{userCount} user …_::_{userCount} users …_" : ["{userCount} корисник …","{userCount} корисници …"],
-    "_{userCount} user_::_{userCount} users_" : ["{userCount} корисник","{userCount} корисници"],
-    "Loading users …" : "Вчитување корисници ...",
-    "Username" : "Корисничко име",
-    "User backend" : "Задна страна на корисник",
-    "Add user to group" : "Додади корисник во група",
-    "Server error while trying to add WebAuthn device" : "Грешка на серверот при обид за додавање на WEBAuthn уред",
-    "Name your device" : "Име на вашиот уред",
-    "Follow us on Twitter" : "Следете не на Twitter"
+    "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "Користите <strong>{usage}</strong> од <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)"
 },
 "nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
