@@ -50,6 +50,7 @@ OC.L10N.register(
     "Uploading attachment failed." : "附件上傳失敗。",
     "Insert an attachment" : "插入附件",
     "Failed to insert from Files" : "從檔案插入失敗",
+    "Failed to create attachment" : "無法創建附件",
     "Preview options" : "預覽選項",
     "Text only" : "僅文字",
     "Show link preview" : "顯示連結預覽",
@@ -121,12 +122,14 @@ OC.L10N.register(
     "Save changes" : "保存更改",
     "Cancel" : "取消",
     "URL" : "URL",
+    "Attachments cannot be created or uploaded because this file is shared from another cloud." : "無法創建或上傳附件，因為此檔案來自另一個雲端分享。",
     "Upload from computer" : "從電腦上傳",
     "Insert from Files" : "從檔案插入",
     "Formatting help" : "格式化說明",
     "Link to file or folder" : "連結至檔案或資料夾",
     "Link to website" : "連結至網站",
     "Update link" : "更新鏈接",
+    "{menuItemName}, \"{selectedSubMenuItemName}\" is selected" : "{menuItemName}，已選取「{selectedSubMenuItemName}」",
     "_%n word_::_%n words_" : ["%n 個單詞"],
     "_%n char_::_%n chars_" : ["%n 個字母"],
     "Remaining actions" : "剩餘操作",
@@ -148,6 +151,7 @@ OC.L10N.register(
     "No command found" : "找不到命令",
     "No user found" : "找不到用戶",
     "No suggestion found" : "找不到建議",
+    "Uploading attachments is disabled because the file is shared from another cloud." : "上傳附件已停用，因為該檔案來自另一個雲端分享。",
     "Upload" : "上傳",
     "Insert Table" : "插入數據庫表",
     "Smart Picker" : "智能選擇器",
@@ -203,6 +207,8 @@ OC.L10N.register(
     "Option" : "選項",
     "Formatting" : "正在格式化",
     "Select file or folder to link to" : "選擇要連結的檔案或資料夾",
+    "Choose" : "選擇",
+    "Choose {file}" : "選擇 {file}",
     "Add folder description" : "新增資料夾描述",
     "\"{name}\" already exist!" : "「{name}」已存在！",
     "Created \"{name}\"" : "已建立「{name}」",
@@ -215,17 +221,12 @@ OC.L10N.register(
     "Document has been changed outside of the editor. The changes cannot be applied" : "文件已在編輯器外變更。無法套用變更。",
     "Document could not be loaded. Please check your internet connection." : "無法載入文件。請檢查您的網路連線。",
     "Document idle for {timeout} minutes, click to continue editing" : "文件已閒置 {timeout} 分鐘。點選以繼續編輯",
-    "Show author colors" : "顯示作者顏色",
-    "Author colors are only shown until everyone has closed the document." : "僅在所有人都關閉文件前才顯示文件顏色。",
-    "Connection failed." : "連線失敗。",
     "Detect language" : "檢測語言",
     "Callouts" : "標記",
     "Info" : "資訊",
     "Success" : "成功",
     "Warning" : "警告",
     "Danger" : "危險",
-    "Control" : "掌控",
-    "Add notes, lists or links …" : "加入筆記、清單或連結…",
     "Start writing, or try '/' to add, '@' to mention…" : "開始撰寫，或試試看「/」新增、「@」提及……"
 },
 "nplurals=1; plural=0;");
