@@ -19,7 +19,7 @@ OC.L10N.register(
     "An error occurred. Please contact your admin." : "Der opstod et problem. Kontakt venligst administratoren.",
     "Invalid image" : "Ugyldigt billede",
     "No temporary profile picture available, try again" : "Intet midlertidigt profilbillede tilgængeligt, prøv igen",
-    "No crop data provided" : "Ingen beskæringsdata give",
+    "No crop data provided" : "Ingen beskæringsdata givet",
     "No valid crop data provided" : "Der er ikke angivet gyldige data om beskæring",
     "Crop is not square" : "Beskæringen er ikke kvadratisk",
     "State token does not match" : "Forkert tilstandsnøgle",
@@ -51,6 +51,11 @@ OC.L10N.register(
     "No translation provider available" : "Ingen tilgængelig oversættelsesudbyder",
     "Could not detect language" : "Kunne ikke finde sprog",
     "Unable to translate" : "Kan ikke oversætte",
+    "[%d / %d]: %s" : "[%d / %d]: %s",
+    "Repair step:" : "Reparationstrin:",
+    "Repair info:" : "Reparationsinfo:",
+    "Repair warning:" : "Reparationsadvarsel:",
+    "Repair error:" : "Reparationsfejl:",
     "Nextcloud Server" : "Nextcloud Server",
     "Some of your link shares have been removed" : "Nogle af dine delte links er blevet fjernet",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Pga et sikkerhedshul har vi været nødt til at fjerne nogle af dine delte links. Se linket for mere information.",
@@ -58,11 +63,6 @@ OC.L10N.register(
     "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Indtast din abonnementsnøgle i support app for at øge konto grænsen. Dette giver dig også alle yderligere fordele, som Nextcloud Enterprise tilbyder og anbefales stærkt til driften i virksomheder.",
     "Learn more ↗" : "Lær mere ↗",
     "Preparing update" : "Forbereder opdatering",
-    "[%d / %d]: %s" : "[%d / %d]: %s",
-    "Repair step:" : "Reparationstrin:",
-    "Repair info:" : "Reparationsinfo:",
-    "Repair warning:" : "Reparationsadvarsel:",
-    "Repair error:" : "Reparationsfejl:",
     "Please use the command line updater because updating via browser is disabled in your config.php." : "Brug venligst kommandolinjeopdateringen, fordi opdatering via browser er deaktiveret i din config.php.",
     "Turned on maintenance mode" : "Startede vedligeholdelsestilstand",
     "Turned off maintenance mode" : "Slå vedligeholdelsestilstand fra",
@@ -76,9 +76,11 @@ OC.L10N.register(
     "Reset log level" : "Nulstil logningsniveau",
     "Starting code integrity check" : "Begynder tjek af kodeintegritet",
     "Finished code integrity check" : "Fuldførte tjek af kodeintegritet",
-    "%s (incompatible)" : "%s (inkombatible)",
+    "%s (incompatible)" : "%s (inkompatibel)",
     "The following apps have been disabled: %s" : "Følgende apps er blevet deaktiveret: %s",
     "Already up to date" : "Allerede opdateret",
+    "Unknown" : "Ukendt",
+    "PNG image" : "PNG billede",
     "Error occurred while checking server setup" : "Der opstod fejl under tjek af serveropsætningen",
     "For more details see the {linkstart}documentation ↗{linkend}." : "For flere detaljer se {linkstart}dokumentationen ↗{linkend}.",
     "unknown text" : "ukendt tekst",
@@ -146,6 +148,8 @@ OC.L10N.register(
     "Account name" : "Kontonavn",
     "Server side authentication failed!" : "Server side godkendelse mislykkedes!",
     "Please contact your administrator." : "Kontakt venligst din administrator.",
+    "Session error" : "Sessionsfejl",
+    "It appears your session token has expired, please refresh the page and try again." : "Det ser ud til, at dit sessionstoken er udløbet. Opdater venligst siden og prøv igen.",
     "An internal error occurred." : "Der opstod en intern fejl.",
     "Please try again or contact your administrator." : "Kontakt venligst din administrator.",
     "Password" : "Adgangskode",
@@ -265,7 +269,7 @@ OC.L10N.register(
     "Continue" : "Videre",
     "(all selected)" : "(alle valgt)",
     "({count} selected)" : "({count} valgt)",
-    "Error loading file exists template" : "Fejl ved inlæsning af; fil eksistere skabelon",
+    "Error loading file exists template" : "Fejl ved indlæsning af 'fil eksisterer' skabelon",
     "Saving …" : "Gemmer…",
     "seconds ago" : "få sekunder siden",
     "Connection to server lost" : "Forbindelsen til serveren er tabt",
@@ -298,9 +302,9 @@ OC.L10N.register(
     "Admin" : "Admin",
     "Help" : "Hjælp",
     "Access forbidden" : "Adgang forbudt",
+    "Back to %s" : "Tilbage til %s",
     "Page not found" : "Siden blev ikke fundet",
     "The page could not be found on the server or you may not be allowed to view it." : "Siden kunne ikke findes på serveren, eller du har muligvis ikke tilladelse til at se den.",
-    "Back to %s" : "Tilbage til %s",
     "Too many requests" : "For mange resultater",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Der har været for mange forespørgsmåler fra dit netværk. Forsøg igen senere eller kontakt din administrator hvis dette er en fejl.",
     "Error" : "Fejl",
@@ -355,9 +359,9 @@ OC.L10N.register(
     "Cancel login" : "Annuller login",
     "Enhanced security is enforced for your account. Choose which provider to set up:" : "Forbedret sikkerhed er påkrævet for din konto. Vælg hvilken udbyder at opsætte:",
     "Error while validating your second factor" : "Fejl i valideringen af din anden faktor login",
-    "Access through untrusted domain" : "Tilgå gennem et utroværdigt domæne.",
-    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Kontakt venligst din administrator. Hvis du er administratoren af denne server, skal du konfigurerer \"trusted-domains\" i filen config/config.php. Et eksempel på hvordan kan findes i filen config/config.sample.php",
-    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Nærmere information om hvordan %1$s indstilles kan findes i dokumentationen %2$s. ",
+    "Access through untrusted domain" : "Adgang gennem et utroværdigt domæne.",
+    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Kontakt venligst din administrator. Hvis du er administratoren af denne server, skal du konfigurere \"trusted-domains\" i filen config/config.php. Et eksempel på hvordan kan findes i filen config/config.sample.php",
+    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Nærmere information om hvordan dette indstilles kan findes i %1$sdokumentationen%2$s.",
     "App update required" : "Opdatering af app påkræves",
     "%1$s will be updated to version %2$s" : "%1$s vil blive opdateret til version %2$s",
     "The following apps will be updated:" : "Følgende app vil blive opdateret:",
@@ -376,16 +380,12 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Denne %s-instans befinder sig i vedligeholdelsestilstand for øjeblikket, hvilket kan tage et stykke tid.",
     "This page will refresh itself when the instance is available again." : "Denne side vil genopfriske sig selv, når instancen er tilgængelig igen.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Kontakt systemadministratoren, hvis denne meddelelse fortsætter eller optrådte uventet.",
-    "Currently open" : "I øjeblikket åben",
-    "Login with username or email" : "Log ind med brugernavn eller e-mail",
-    "Login with username" : "Log ind med brugernavn",
     "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Chat, video kald, skærmdeling, online møder og web konferencer - i din browser og med mobil apps.",
     "You have not added any info yet" : "Du har ikke tilføjet nogen information endnu",
     "{user} has not added any info yet" : "{user} har ikke tilføjet nogen oplysninger endnu",
     "Error opening the user status modal, try hard refreshing the page" : "Fejl ved åbning af brugerstatusmodal. Prøv at opdatere siden",
     "Edit Profile" : "Rediger profil",
     "The headline and about sections will show up here" : "Overskriften og om sektionerne vises her",
-    "Error loading message template: {error}" : "Fejl ved indlæsning af besked skabelon: {error}",
     "Very weak password" : "Meget svagt kodeord",
     "Weak password" : "Svagt kodeord",
     "So-so password" : "Jævnt kodeord",
@@ -393,7 +393,7 @@ OC.L10N.register(
     "Strong password" : "Stærkt kodeord",
     "Profile not found" : "Profil ikke fundet",
     "The profile does not exist." : "Profilen eksisterer ikke.",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Dine data mappe og filer er sandsynligvis tilgængelige fra internettet fordi .htaccess filen ikke virker.",
+    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Din data mappe og filer er sandsynligvis tilgængelige fra internettet fordi .htaccess filen ikke virker.",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "For information om, hvordan du konfigurerer din server korrekt se <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dokumentationen</a>.",
     "<strong>Create an admin account</strong>" : "<strong>Opret en administrator konto</strong>",
     "New admin account name" : "Navn på ny admin konto",
