@@ -35,16 +35,16 @@ OC.L10N.register(
     "Reset your password" : "Resetirajte svoju zaporku",
     "Internal error" : "Unutarnja pogreška",
     "Not found" : "Nije pronađeno",
-    "Nextcloud Server" : "Nextcloud poslužitelj",
-    "Some of your link shares have been removed" : "Uklonjene su neke od vaših dijeljenih poveznica",
-    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Zbog sigurnosne pogreške morali smo ukloniti neke od vaših dijeljenih poveznica. Za više informacija pogledajte poveznicu.",
-    "Learn more ↗" : "Saznajte više ↗",
-    "Preparing update" : "Priprema ažuriranja",
     "[%d / %d]: %s" : "[%d / %d]: %s",
     "Repair step:" : "Korak ispravljanja pogreške:",
     "Repair info:" : "Informacije o ispravljanju pogreške:",
     "Repair warning:" : "Upozorenje o ispravljanju pogreške:",
     "Repair error:" : "Pogreška ispravljanja pogreške:",
+    "Nextcloud Server" : "Nextcloud poslužitelj",
+    "Some of your link shares have been removed" : "Uklonjene su neke od vaših dijeljenih poveznica",
+    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Zbog sigurnosne pogreške morali smo ukloniti neke od vaših dijeljenih poveznica. Za više informacija pogledajte poveznicu.",
+    "Learn more ↗" : "Saznajte više ↗",
+    "Preparing update" : "Priprema ažuriranja",
     "Turned on maintenance mode" : "Način rada za održavanje uključen",
     "Turned off maintenance mode" : "Način rada za održavanje isključen",
     "Maintenance mode is kept active" : "Način rada za održavanje održan",
@@ -60,6 +60,7 @@ OC.L10N.register(
     "%s (incompatible)" : "%s (nije kompatibilno)",
     "The following apps have been disabled: %s" : "Sljedeće aplikacije su onemogućene: %s",
     "Already up to date" : "Nema potrebe za ažuriranjem",
+    "Unknown" : "Nepoznata pogreška",
     "Error occurred while checking server setup" : "Pogreška prilikom provjere postavki poslužitelja",
     "For more details see the {linkstart}documentation ↗{linkend}." : "Više informacija potražite u {linkstart}dokumentaciji ↗{linkend}.",
     "unknown text" : "nepoznati tekst",
@@ -208,8 +209,8 @@ OC.L10N.register(
     "Admin" : "Administrator",
     "Help" : "Pomoć",
     "Access forbidden" : "Pristup zabranjen",
-    "Page not found" : "Stranica nije pronađena",
     "Back to %s" : "Natrag na %s",
+    "Page not found" : "Stranica nije pronađena",
     "Too many requests" : "Previše zahtjeva",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Zaprimljeno je previše zahtjeva iz vaše mreže. Pokušajte kasnije ili se obratite administratoru ako se radi o pogrešci.",
     "Error" : "Pogreška",
@@ -277,7 +278,6 @@ OC.L10N.register(
     "This page will refresh itself when the instance is available again." : "Ova će se stranica osvježiti kada je instanca ponovno dostupna.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Obratite se administratoru sustava ako se ova poruka ponavlja ili se pojavila neočekivano.",
     "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Razmjenjivanje poruka, video pozivi, dijeljenje zaslona, sastanci na mreži i web-konferencije – putem preglednika i mobilnih aplikacija.",
-    "Error loading message template: {error}" : "Pogrešno učitavanje predloška za poruke: {error}",
     "Very weak password" : "Zaporka vrlo slaba",
     "Weak password" : "Zaporka Slaba",
     "So-so password" : "Zaporka prosječne jačine",
