@@ -42,16 +42,16 @@ OC.L10N.register(
     "No translation provider available" : "Nissunu servìtziu de tradutzione a disponimentu",
     "Could not detect language" : "Impossìbile rilevare sa lìngua",
     "Unable to translate" : "Impossìbile tradùere",
-    "Nextcloud Server" : "Serbidore de Nextcloud",
-    "Some of your link shares have been removed" : "Carchi ligòngiu de cumpartzidura tuo nch'est istadu bogadu",
-    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Pro un'errore de seguresa nch'amus dèpidu bogare carchi ligòngiu de cumpartzidura. Càstia su ligòngiu pro àteras informatziones.",
-    "Learn more ↗" : "Àteras informatziones ↗",
-    "Preparing update" : "Aprontende s'agiornamentu",
     "[%d / %d]: %s" : "[%d / %d]: %s",
     "Repair step:" : "Passu de s'acontzu:",
     "Repair info:" : "Informatziones de s'acontzu:",
     "Repair warning:" : "Avisu de s'acontzu:",
     "Repair error:" : "Errore in s'acontzu:",
+    "Nextcloud Server" : "Serbidore de Nextcloud",
+    "Some of your link shares have been removed" : "Carchi ligòngiu de cumpartzidura tuo nch'est istadu bogadu",
+    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Pro un'errore de seguresa nch'amus dèpidu bogare carchi ligòngiu de cumpartzidura. Càstia su ligòngiu pro àteras informatziones.",
+    "Learn more ↗" : "Àteras informatziones ↗",
+    "Preparing update" : "Aprontende s'agiornamentu",
     "Turned on maintenance mode" : "Furriadu a modalidade de mantenidura",
     "Turned off maintenance mode" : "Modalidade de mantenidura disativada",
     "Maintenance mode is kept active" : "Sa modalidade de mantenidura abarrat ativa",
@@ -67,6 +67,7 @@ OC.L10N.register(
     "%s (incompatible)" : "%s (non cumpatìbile)",
     "The following apps have been disabled: %s" : "Is aplicatziones in fatu sunt istadas disativadas: %s",
     "Already up to date" : "Giai agiornadu",
+    "Unknown" : "Disconnotu",
     "Error occurred while checking server setup" : "Ddoe at àpidu un'errore in su controllu de sa cunfiguratzione de su serbidore",
     "For more details see the {linkstart}documentation ↗{linkend}." : "Pro àteros detàllios controlla sa {linkstart}documentatzione ↗{linkend}.",
     "unknown text" : "testu disconnotu",
@@ -120,8 +121,6 @@ OC.L10N.register(
     "Account name or email" : "Nùmene de su contu o indiritzu de posta",
     "Server side authentication failed!" : "Autenticatzione de s'ala de su serbidore faddida!",
     "Please contact your administrator." : "Cuntata s'amministratzione.",
-    "Temporary error" : "Errore temporàneu",
-    "Please try again." : "Torra·nce a proare",
     "An internal error occurred." : "B'at àpidu un'errore internu.",
     "Please try again or contact your administrator." : "Torra a proare o cuntata s'amministratzione.",
     "Password" : "Crae",
@@ -243,11 +242,12 @@ OC.L10N.register(
     "Collaborative tags" : "Etichetas collaborativas",
     "No tags found" : "Peruna eticheta agatada",
     "Personal" : "Personale",
+    "Accounts" : "Accounts",
     "Admin" : "Amministratzione",
     "Help" : "Agiudu",
     "Access forbidden" : "Atzessu proibidu",
-    "Page not found" : "Pàgina no agatada",
     "Back to %s" : "A coa a %s",
+    "Page not found" : "Pàgina no agatada",
     "Too many requests" : "Tropu dimandas",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Tropu rechestas sunt arribadas dae sa rete tua. Torra a proare prus a tardu o cuntata s'amministradore tuo chi ddoe at un'errore.",
     "Error" : "Errore",
@@ -317,13 +317,9 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Immoe custa istàntzia de %s est in modalidade de mantenidura, e podet trigare unu pagu.",
     "This page will refresh itself when the instance is available again." : "Custa pàgina s'at a atualizare cando s'istàntzia at a èssere torra a disponimentu.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Cuntata s'amministratzione de sistema si custu messàgiu abarrat o torrat a cumpàrrere.",
-    "Currently open" : "Abertos immoe",
-    "Login with username or email" : "Atzede cun nùmene de utente o indiritzu de posta eletrònica",
-    "Login with username" : "Atzede cun nùmene de utente",
     "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Tzarradas, video mutidas, cumpartzidura de s'ischermu, reuniones in lìnia e vìdeo-cunferèntzias – in su navigadore tuo e cun aplicatziones mòbiles.",
     "Edit Profile" : "Modìfica su profilu",
     "The headline and about sections will show up here" : "Is setziones de tìtulu e informatziones ant a èssere ammustradas inoghe",
-    "Error loading message template: {error}" : "Errore in su carrigamentu de su modellu de messàgiu: {error}",
     "Very weak password" : "Crae dèbile meda",
     "Weak password" : "Crae dèbile",
     "So-so password" : "Crae aici aici",
