@@ -27,6 +27,7 @@ OC.L10N.register(
     "Could not complete login" : "Prijave ni mogoče dokončati",
     "State token missing" : "Manjka žeton stanja",
     "Your login token is invalid or has expired" : "Prijavni žeton je neveljaven, ali pa je že potekel.",
+    "Please use original client" : "Uporabite izvirnega odjemalca",
     "This community release of Nextcloud is unsupported and push notifications are limited." : "Ta skupnostna objava oblaka Nextcloud ni podprta, nekatera potisna obvestila so zato omejena.",
     "Login" : "Prijava",
     "Unsupported email length (>255)" : "Nepodprta dolžina sporočila ( > 255 )",
@@ -51,6 +52,11 @@ OC.L10N.register(
     "No translation provider available" : "Ponudnik prevoda ni na voljo.",
     "Could not detect language" : "Ni mogoče zaznati jezika.",
     "Unable to translate" : "Ni mogoče prevajati",
+    "[%d / %d]: %s" : "[%d / %d]: %s",
+    "Repair step:" : "Korak nadgradnje:",
+    "Repair info:" : "Podrobnosti nadgradnje:",
+    "Repair warning:" : "Opozorilo nadgradnje:",
+    "Repair error:" : "Napaka nadgradnje:",
     "Nextcloud Server" : "Strežnik Nextcloud",
     "Some of your link shares have been removed" : "Nekatere povezave za souporabo so bile odstranjene.",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Zaradi varnostnih razlogov so bile nekatere povezave odstranjene. Več podrobnosti je na voljo v uradno izdanem opozorilu.",
@@ -58,11 +64,6 @@ OC.L10N.register(
     "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Vpišite ključ naročila podpornega programa in povečajte omejitev za uporabnika. S tem pridobite tudi vse dodatne ugodnosti, ki jih omogoča Poslovno okolje Nextcloud. Način je zelo priporočljiv za podjetja.",
     "Learn more ↗" : "Več o tem ↗",
     "Preparing update" : "Poteka priprava na posodobitev ...",
-    "[%d / %d]: %s" : "[%d / %d]: %s",
-    "Repair step:" : "Korak nadgradnje:",
-    "Repair info:" : "Podrobnosti nadgradnje:",
-    "Repair warning:" : "Opozorilo nadgradnje:",
-    "Repair error:" : "Napaka nadgradnje:",
     "Please use the command line updater because updating via browser is disabled in your config.php." : "Posodobitev sistema je treba izvesti v ukazni vrstici, ker je posodabljanje z brskalnikom v config.php onemogočeno.",
     "Turned on maintenance mode" : "Vzdrževalni način je omogočen ...",
     "Turned off maintenance mode" : "Vzdrževalni način je onemogočen.",
@@ -79,6 +80,101 @@ OC.L10N.register(
     "%s (incompatible)" : "%s (neskladno)",
     "The following apps have been disabled: %s" : "Zaradi neskladnosti so onemogočeni naslednji programi: %s.",
     "Already up to date" : "Sistem je že posodobljen",
+    "Windows Command Script" : "Ukazni skript Windows",
+    "Electronic book document" : "Dokument elektronske knjige",
+    "TrueType Font Collection" : "Zbirka pisav TTF",
+    "Web Open Font Format" : "Odprti zapis spletne pisave",
+    "GPX geographic data" : "Geografski podatki GPX",
+    "Gzip archive" : "Arhiv GZIP",
+    "Adobe Illustrator document" : "Dokument Adobe Illustrator",
+    "Java source code" : "Izvorna koda Java",
+    "JavaScript source code" : "Izvorna koda Javascript",
+    "JSON document" : "Dokument JSON",
+    "Microsoft Access database" : "Podatkovna zbirka Microsoft Access",
+    "Microsoft OneNote document" : "Dokument Microsoft OneNote",
+    "Microsoft Word document" : "Dokument Microsoft Word",
+    "Unknown" : "Neznano",
+    "PDF document" : "Dokument PDF",
+    "PostScript document" : "Dokument PostScript",
+    "RSS summary" : "Povzetek virov RSS",
+    "Android package" : "Programski paket Android",
+    "KML geographic data" : "Geografski podatki KLM",
+    "KML geographic compressed data" : "Stisnjeni geografski podatki KLM",
+    "Lotus Word Pro document" : "Dokument Lotus Word Pro",
+    "Excel spreadsheet" : "Preglednica Excel",
+    "Excel add-in" : "Razširitev Excel",
+    "Excel spreadsheet template" : "Predloga preglednice Excel",
+    "Outlook Message" : "Sporočilo Outlook",
+    "PowerPoint presentation" : "Predstavitev PowerPoint",
+    "PowerPoint add-in" : "Razširitev PowerPoint",
+    "PowerPoint presentation template" : "Predloga predstavitve PowerPoint",
+    "Word document" : "Dokument Word",
+    "ODF formula" : "Formula ODF",
+    "ODG drawing" : "Risba ODG",
+    "ODG template" : "Predloga ODG",
+    "ODP presentation" : "Predstavitev ODP",
+    "ODP template" : "Predloga ODP",
+    "ODS spreadsheet" : "Preglednica ODS",
+    "ODS template" : "Predloga ODS",
+    "ODT document" : "Dokument ODT",
+    "ODT template" : "Predloga ODT",
+    "PowerPoint 2007 presentation" : "Predstavitev PowerPoint 2007",
+    "PowerPoint 2007 presentation template" : "Predloga predstavitve PowerPoint 2007",
+    "Excel 2007 spreadsheet" : "Preglednica Excel 2007",
+    "Excel 2007 spreadsheet template" : "Predloga preglednice Excel 2007",
+    "Word 2007 document" : "Dokument Word 2007",
+    "Word 2007 document template" : "Predloga dokumenta Word 2007",
+    "Microsoft Visio document" : "Dokument Microsoft Visio",
+    "WordPerfect document" : "Dokument WordPerfect",
+    "7-zip archive" : "Arhiv 7-zip",
+    "Bzip2 archive" : "Arhiv Bzip2",
+    "Debian package" : "Programski paket Debian",
+    "FictionBook document" : "Dokument FictionBook",
+    "Unknown font" : "Neznan zapis pisave",
+    "Krita document" : "Dokument Krita",
+    "Mobipocket e-book" : "Elektronska knjiga Mobipocket",
+    "Windows Installer package" : "Namestitveni paket Windows",
+    "Perl script" : "Skript Perl",
+    "PHP script" : "Skript PHP",
+    "Tar archive" : "Arhiv Tar",
+    "XML document" : "Dokument XML",
+    "YAML document" : "Dokument YAML",
+    "Zip archive" : "Arhiv ZIP",
+    "Zstandard archive" : "Arhiv Zstandard",
+    "AAC audio" : "Zvok AAC",
+    "FLAC audio" : "Zvok FLAC",
+    "MPEG-4 audio" : "Zvok MPEG-4",
+    "MP3 audio" : "Zvok MP3",
+    "Ogg audio" : "Zvok OGG",
+    "WebM audio" : "Zvok WebM",
+    "Windows BMP image" : "Slika Windows BMP",
+    "EMF image" : "Slika EMF",
+    "GIF image" : "Slika GIF",
+    "HEIC image" : "Slika HEIC",
+    "HEIF image" : "Slika HEIF",
+    "JPEG image" : "Slika JPEG",
+    "PNG image" : "Slika PNG",
+    "SVG image" : "Risba SVG",
+    "TIFF image" : "Slika TIFF",
+    "WebP image" : "Slika WebP",
+    "Digital raw image" : "Surova digitalna slika",
+    "Windows Icon" : "Ikona Windows",
+    "VCS/ICS calendar" : "Koledar VCS/ICS",
+    "CSS stylesheet" : "Slogovna predloga CSS",
+    "CSV document" : "Dokument CSV",
+    "HTML document" : "Dokument HTML",
+    "Markdown document" : "Dokument Markdown",
+    "Plain text document" : "Besedilni dokument",
+    "Rich Text document" : "Dokument z obogatenim besedilom",
+    "Electronic business card" : "Elektronska poslovna kartica",
+    "C++ source code" : "Izvorna koda C++",
+    "LDIF address book" : "Imenik LDIF",
+    "NFO document" : "Dokument NFO",
+    "PHP source" : "Izvorna koda PHP",
+    "Python script" : "Skript Python",
+    "MPEG video" : "Video MPEG",
+    "DV video" : "Video DV",
+    "MPEG-4 video" : "Video MPEG-4",
     "Error occurred while checking server setup" : "Prišlo je do napake med preverjanjem nastavitev strežnika",
     "For more details see the {linkstart}documentation ↗{linkend}." : "Za več podrobnosti preverite {linkstart}dokumentacijo ↗{linkend}.",
     "unknown text" : "neznano besedilo",
@@ -146,8 +242,8 @@ OC.L10N.register(
     "Account name" : "Ime računa",
     "Server side authentication failed!" : "Overitev na strani strežnika je spodletela!",
     "Please contact your administrator." : "Stopite v stik s skrbnikom sistema.",
-    "Temporary error" : "Začasna napaka",
-    "Please try again." : "Poskusite znova",
+    "Session error" : "Napaka seje",
+    "It appears your session token has expired, please refresh the page and try again." : "Žeton seje je verjetno potekel. Osvežite stran in poskusite znova.",
     "An internal error occurred." : "Prišlo je do notranje napake.",
     "Please try again or contact your administrator." : "Poskusite znova ali pa stopite v stik s skrbnikom sistema.",
     "Password" : "Geslo",
@@ -170,6 +266,7 @@ OC.L10N.register(
     "Schedule work & meetings, synced with all your devices." : "Načrtujte delo in sestanke, ki se samodejno usklajujejo z vsemi vašimi napravami.",
     "Keep your colleagues and friends in one place without leaking their private info." : "Združite sodelavce in prijatelje na enem mestu brez skrbi za njihove zasebne podatke.",
     "Simple email app nicely integrated with Files, Contacts and Calendar." : "Enostaven program za pošto se odlično povezuje z Datotekami, Stiki in Koledarjem.",
+    "Chatting, video calls, screen sharing, online meetings and web conferencing – in your browser and with mobile apps." : "Klepet, videopogovori, souporaba zaslona, spletni sestanki in spletne konference – v spletnem brskalniku ali na mobilnih napravah.",
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Sodelovanje pri ustvarjanju dokumentov, preglednic in predstavitev, ki zahtevajo storitev Collabora Online.",
     "Distraction free note taking app." : "Enostavno beleženje in zapisovanje",
     "Recommended apps" : "Priporočeni programi",
@@ -206,9 +303,25 @@ OC.L10N.register(
     "Login form is disabled." : "Prijavni obrazec je onemogočen.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Prijavni obrazec Nextcloud je onemogočen. Če je mogoče, izberite drug način prijave, ali pa stopite v stik s skrbnikom sistema.",
     "More actions" : "Več dejanj",
+    "Password is too weak" : "Geslo je prešibko",
+    "Password is weak" : "Geslo je šibko",
+    "Password is average" : "Geslo je povprečno",
+    "Password is strong" : "Geslo je močno",
+    "Password is very strong" : "Geslo je zelo močno",
+    "Password is extremely strong" : "Geslo je izjemno močno",
+    "Unknown password strength" : "Neznana moč gesla",
+    "Your data directory and files are probably accessible from the internet because the <code>.htaccess</code> file does not work." : "Podatkovni imenik in datoteke so verjetno dostopne s spleta, ker datoteka <code>.htaccess</code> ne deluje.",
+    "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "Za podrobnosti o pravilnih nastavitvah strežnika {linkStart}preglejte dokumentacijo{linkEnd}",
+    "Autoconfig file detected" : "Zaznana je datoteka za samodejno nastavitev",
+    "The setup form below is pre-filled with the values from the config file." : "Namestitveni obrazec je izpolnjen iz vrednostmi, prevzetimi iz nastavitvene datoteke.",
     "Security warning" : "Varnostno opozorilo",
+    "Create administration account" : "Ustvari skrbniški račun",
+    "Administration account name" : "Ime skrbniškega računa",
+    "Administration account password" : "Geslo skrbniškega računa",
     "Storage & database" : "Shramba in podatkovna zbirka",
     "Data folder" : "Podatkovna mapa",
+    "Database configuration" : "Nastavitve podatkovne zbirke",
+    "Only {firstAndOnlyDatabase} is available." : "Na voljo je le {firstAndOnlyDatabase}",
     "Install and activate additional PHP modules to choose other database types." : "Namestite in omogočite dodatne module PHP za izbor drugih vrst podatkovnih zbirk.",
     "For more details check out the documentation." : "Za več podrobnosti preverite dokumentacijo.",
     "Performance warning" : "Opozorilo učinkovitosti delovanja",
@@ -221,6 +334,7 @@ OC.L10N.register(
     "Database tablespace" : "Razpredelnica podatkovne zbirke",
     "Please specify the port number along with the host name (e.g., localhost:5432)." : "Skupaj z imenom gostitelja je treba določiti tudi številko vrat (na primer localhost:5432).",
     "Database host" : "Gostitelj podatkovne zbirke",
+    "localhost" : "localhost",
     "Installing …" : "Poteka nameščanje ...",
     "Install" : "Namesti",
     "Need help?" : "Ali potrebujete pomoč?",
@@ -276,14 +390,15 @@ OC.L10N.register(
     "Rename" : "Preimenuj",
     "Collaborative tags" : "Sodelovalne oznake",
     "No tags found" : "Ni najdenih oznak",
+    "Clipboard not available, please copy manually" : "Odložišče ni na voljo, kopirajte ročno",
     "Personal" : "Osebno",
     "Accounts" : "Računi",
     "Admin" : "Skrbništvo",
     "Help" : "Pomoč",
     "Access forbidden" : "Dostop je prepovedan",
+    "Back to %s" : "Nazaj na %s",
     "Page not found" : "Strani ni mogoče najti",
     "The page could not be found on the server or you may not be allowed to view it." : "Strani na strežniku ni mogoče najti ali pa ni ustreznih dovoljenj za prikaz.",
-    "Back to %s" : "Nazaj na %s",
     "Too many requests" : "Zaznanih je preveč sočasnih zahtev",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Iz omrežja je bilo prejetih preveč zahtev. Če je to napaka, stopite v stik s skrbnikom, sicer pa poskusite spet kasneje.",
     "Error" : "Napaka",
@@ -359,16 +474,12 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Strežnik %s je trenutno v vzdrževalnem načinu, kar onemogoča prijavo.",
     "This page will refresh itself when the instance is available again." : "Stran bo samodejno osvežena, ko bo okolje spet pripravljeno za delo.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Če se bo to sporočilo še naprej nepričakovano pojavljalo, stopite v stik s skrbnikom sistema.",
-    "Currently open" : "Trenutno odprto",
-    "Login with username or email" : "Prijava z uporabniškim imenom ali elektronskim naslovom",
-    "Login with username" : "Prijava z uporabniškim imenom",
     "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Klepet, video klici, souporaba zaslonske slike, spletni sestanki in konference – znotraj brskalnika in z mobilnimi napravami.",
     "You have not added any info yet" : "Ni še vpisanih podrobnosti",
     "{user} has not added any info yet" : "Oseba {user} še ni dodala nobenih podrobnosti.",
     "Error opening the user status modal, try hard refreshing the page" : "Prišlo je do napake pri odpiranju modalnega okna stanja uporabnika. Napako je mogoče razrešiti z osvežitvijo strani.",
     "Edit Profile" : "Uredi profil",
     "The headline and about sections will show up here" : "Naslovnica in odsek s podatki bo prikazan na tem mestu.",
-    "Error loading message template: {error}" : "Napaka nalaganja predloge sporočil: {error}",
     "Very weak password" : "Zelo šibko geslo",
     "Weak password" : "Šibko geslo",
     "So-so password" : "Slabo geslo",
@@ -378,6 +489,9 @@ OC.L10N.register(
     "The profile does not exist." : "Profil ne obstaja.",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Podatkovna mapa in datoteke so najverjetneje javno dostopni v omrežju, ker datoteka .htaccess ni ustrezno nastavljena.",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Več podrobnosti, kako pravilno nastaviti strežnik, je zapisanih v <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dokumentaciji</a>.",
+    "<strong>Create an admin account</strong>" : "<strong>Ustvari skrbniški račun</strong>",
+    "New admin account name" : "Ime novega skrbniškega računa",
+    "New admin password" : "Geslo novega skrbniškega računa",
     "Show password" : "Pokaži geslo",
     "Toggle password visibility" : "Preklopi vidnost gesla",
     "Configure the database" : "Nastavi podatkovno zbirko",
