@@ -5,9 +5,9 @@ OC.L10N.register(
     "This can usually be fixed by giving the web server write access to the config directory." : "Dit kan opgelost worden door de config map op de webserver schrijfrechten te geven.",
     "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Maar, als je liever config.php alleen-lezen wilt houden, stel dan de optie \"config_is_read_only\" in op true.",
     "See %s" : "Zie %s",
-    "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "De bestanden van app %1$szijn niet correct vervangen. Zorg ervoor dat de versie compatible is met de server.",
     "Sample configuration detected" : "Voorbeeld configuratie gevonden",
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Er is gedetecteerd dat de voorbeeld configuratie is gekopieerd. Dit kan je installatie beschadigen en wordt dan ook niet ondersteund. Lees de documentatie voordat je wijzigingen aan config.php doorvoert",
+    "The page could not be found on the server." : "Deze pagina kon niet gevonden worden op de server",
     "%s email verification" : "%s e-mail verificatie",
     "Email verification" : "E-mail verificatie",
     "Click the following button to confirm your email." : "Klik op de knop om je e-mail te bevestigen.",
@@ -18,7 +18,6 @@ OC.L10N.register(
     "%1$s, %2$s and %3$s" : "%1$s, %2$s en %3$s",
     "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s en %4$s",
     "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s en %5$s",
-    "Education Edition" : "Onderwijs Editie",
     "Enterprise bundle" : "Zakelijke bundel",
     "Groupware bundle" : "Groupware bundel",
     "Hub bundle" : "Hub bundel",
@@ -35,9 +34,6 @@ OC.L10N.register(
     "The following platforms are supported: %s" : "De volgende platforms worden ondersteund: %s",
     "Server version %s or higher is required." : "Serverversie %s of hoger vereist.",
     "Server version %s or lower is required." : "Serverversie %s of lager vereist.",
-    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "Ingelogde gebruiken moet beheerder, sub-beheerder of gebruiker met speciale rechten om deze instelling te veranderen zijn",
-    "Logged in user must be an admin or sub admin" : "Ingelogde gebruiker moet een beheerder of subbeheerder zijn",
-    "Logged in user must be an admin" : "Ingelogde gebruiker moet een beheerder zijn",
     "Wiping of device %s has started" : "Leegmaken van toestel %sis gestart",
     "Wiping of device »%s« has started" : "Leegmaken van toestel  \"%s\" is gestart",
     "»%s« started remote wipe" : "\"%s\" startte leegmaken op afstand",
@@ -54,7 +50,10 @@ OC.L10N.register(
     "Unknown filetype" : "Onbekend bestandsformaat",
     "Invalid image" : "Ongeldige afbeelding",
     "Avatar image is not square" : "Avatar afbeelding is niet vierkant",
+    "Files" : "Bestanden",
     "View profile" : "Bekijk profiel",
+    "_%nh_::_%nh_" : ["%nh","%nh"],
+    "Local time: %s" : "Lokale tijd: %s",
     "today" : "vandaag",
     "tomorrow" : "morgen",
     "yesterday" : "gisteren",
@@ -76,25 +75,28 @@ OC.L10N.register(
     "seconds ago" : "seconden geleden",
     "Empty file" : "Leeg bestand",
     "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Module met ID: %s bestaat niet. Schakel die in binnen de app-instellingen of neem contact op met je beheerder.",
+    "Dot files are not allowed" : "Punt-bestanden zijn niet toegestaan",
+    "%1$s (renamed)" : "%1$s (hernoemd)",
+    "renamed file" : "bestand hernoemd",
+    "Invalid parent path" : "Ongeldig bovenliggend pad",
     "File already exists" : "Bestand bestaat al",
     "Invalid path" : "Ongeldig pad",
     "Failed to create file from template" : "Kon geen bestand van het sjabloon maken",
     "Templates" : "Sjablonen",
-    "File name is a reserved word" : "Bestandsnaam is een gereserveerd woord",
-    "File name contains at least one invalid character" : "De bestandsnaam bevat in ieder geval één verboden teken",
-    "File name is too long" : "De bestandsnaam is te lang",
-    "Dot files are not allowed" : "Punt-bestanden zijn niet toegestaan",
+    "Path contains invalid segments" : "Pad bevat ongeldige segmenten",
+    "Filename contains at least one invalid character" : "De bestandsnaam bevat ten minste één ongeldig teken",
     "Empty filename is not allowed" : "Een lege bestandsnaam is niet toegestaan",
     "App \"%s\" cannot be installed because appinfo file cannot be read." : "App \"%s\" kan niet worden geïnstalleerd, omdat het app info bestand niet gelezen kan worden.",
     "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "App \"%s\" kan niet worden geïnstalleerd, omdat deze niet compatible is met deze versie van de server.",
     "__language_name__" : "Nederlands",
     "This is an automatically sent email, please do not reply." : "Dit is een automatisch gegenereerde e-mail, dus reageren is niet mogelijk.",
-    "Help" : "Help",
     "Appearance and accessibility" : "Weergave en toegankelijkheid",
     "Apps" : "Apps",
+    "Personal settings" : "Persoonlijke instellingen",
+    "Administration settings" : "Beheerder instellingen",
     "Settings" : "Instellingen",
     "Log out" : "Uitloggen",
-    "Users" : "Gebruikers",
+    "Accounts" : "Accounts",
     "Email" : "E-mail",
     "Mail %s" : "Mail %s",
     "Phone" : "Telefoon",
@@ -106,32 +108,28 @@ OC.L10N.register(
     "Address" : "Adres",
     "Profile picture" : "Profielafbeelding",
     "About" : "Over",
-    "Full name" : "Volledige naam",
+    "Display name" : "Weergave naam",
     "Headline" : "Hoofdlijn",
-    "Organisation" : "Organisatie",
+    "Organization" : "Organisatie",
     "Role" : "Rol",
-    "Unknown user" : "Onbekende gebruiker",
     "Additional settings" : "Aanvullende instellingen",
-    "MySQL username and/or password not valid" : "MySQL gebruikersnaam en/of wachtwoord ongeldig",
     "You need to enter details of an existing account." : "Geef de details van een bestaand account op.",
     "Oracle connection could not be established" : "Er kon geen verbinding met Oracle worden gemaakt.",
-    "Oracle username and/or password not valid" : "Oracle gebruikersnaam en/of wachtwoord ongeldig",
-    "PostgreSQL username and/or password not valid" : "PostgreSQL gebruikersnaam en/of wachtwoord ongeldig",
-    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OSX wordt niet ondersteund en %s zal niet goed werken op dit platform. Gebruik het op eigen risico!",
     "For the best results, please consider using a GNU/Linux server instead." : "Voor het beste resultaat adviseren wij het gebruik van een GNU/Linux server.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Het lijkt erop dat deze %s versie draait in een 32 bits PHP omgeving en dat open_basedir is geconfigureerd in php.ini. Dat zal leiden tot problemen met bestanden groter dan 4 GB en wordt dus sterk afgeraden.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Verwijder de open_basedir instelling in php.ini of schakel over op de 64bit PHP.",
-    "Set an admin username." : "Stel de gebruikersnaam van de beheerder in.",
     "Set an admin password." : "Stel een beheerders wachtwoord in.",
     "Cannot create or write into the data directory %s" : "Kan niets creëren of wegschrijven in de datadirectory %s",
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "De gedeelde achtergrond %s moet de OCP\\Share_Backend interface implementeren",
     "Sharing backend %s not found" : "De gedeelde backend %s is niet gevonden",
     "Sharing backend for %s not found" : "De gedeelde backend voor %s is niet gevonden",
-    "%1$s shared »%2$s« with you and wants to add:" : "%1$s deelde \"%2$s\" met jou en wil toevoegen:",
-    "%1$s shared »%2$s« with you and wants to add" : "%1$s deelde \"%2$s\" met jou en wil toevoegen",
-    "»%s« added a note to a file shared with you" : "\"%s\" voegde een notitie toe aan een bestand dat met jou is gedeeld",
-    "Open »%s«" : "Open \"%s\"",
+    "%1$s shared %2$s with you" : "%1$s deelde %2$s met jou",
+    "Open %s" : "%s openen",
     "%1$s via %2$s" : "%1$s via %2$s",
+    "%1$s shared %2$s with you and wants to add:" : "%1$s deelde %2$s met jou en wil toevoegen:",
+    "%1$s shared %2$s with you and wants to add" : "%1$s deelde %2$s met jou en wil toevoegen",
+    "%s added a note to a file shared with you" : "%s heeft een notitie toegevoegd aan een bestand dat met jou werd gedeeld",
+    "Unknown share type" : "Onbekend type gedeelde folder",
     "You are not allowed to share %s" : "Je bent niet bevoegd om %s te delen",
     "Cannot increase permissions of %s" : "Kan de machtiging van %s niet verhogen.",
     "Files cannot be shared with delete permissions" : "Bestanden kunnen niet worden gedeeld met verwijdermachtigingen",
@@ -139,10 +137,7 @@ OC.L10N.register(
     "Expiration date is in the past" : "De vervaldatum ligt in het verleden",
     "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Kan de vervaldatum niet meer dan %s dag in de toekomst instellen","Kan de vervaldatum niet meer dan %s dagen in de toekomst instellen"],
     "Sharing is only allowed with group members" : "Delen kan alleen met groepsleden",
-    "Sharing %s failed, because this item is already shared with user %s" : "Delen van %s is mislukt, omdat het object al wordt gedeeld met gebruiker %s",
-    "%1$s shared »%2$s« with you" : "%1$s deelde \"%2$s\" met jou",
-    "%1$s shared »%2$s« with you." : "%1$s deelde \"%2$s\" met jou.",
-    "Click the button below to open it." : "Klik de onderstaande button om te openen.",
+    "Sharing %s failed, because this item is already shared with the account %s" : "Het delen van%s is mislukt, omdat dit item al gedeeld wordt met het account %s",
     "The requested share does not exist anymore" : "De toegang tot de gedeelde folder bestaat niet meer",
     "Could not find category \"%s\"" : "Kan categorie \"%s\" niet vinden",
     "Sunday" : "Zondag",
@@ -190,20 +185,10 @@ OC.L10N.register(
     "Oct." : "Okt.",
     "Nov." : "Nov.",
     "Dec." : "Dec.",
-    "The user limit has been reached and the user was not created." : "Het maximum aantal gebruikers is bereikt en de gebruiker is niet aangemaakt.",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Alleen de volgende tekens zijn toegestaan in een gebruikersnaam: \"a-z\", \"A-Z\", \"0-9\", en \"_.@-\"",
-    "A valid username must be provided" : "Er moet een geldige gebruikersnaam worden opgegeven",
-    "Username contains whitespace at the beginning or at the end" : "De gebruikersnaam bevat spaties aan het begin of aan het eind",
-    "Username must not consist of dots only" : "De gebruikersnaam mag niet uit alleen punten bestaan",
-    "Username is invalid because files already exist for this user" : "Gebruikersnaam is ongeldig omdat er al bestanden voor deze gebruiker bestaan",
     "A valid password must be provided" : "Er moet een geldig wachtwoord worden opgegeven",
-    "The username is already being used" : "De gebruikersnaam bestaat al",
-    "Could not create user" : "Kan gebruiker niet aanmaken.",
-    "User disabled" : "Gebruiker uitgeschakeld",
     "Login canceled by app" : "Inloggen geannuleerd door app",
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "App \"%1$s\" kan niet worden geïnstalleerd, omdat de volgende afhankelijkheden niet zijn ingevuld: %2$s",
     "a safe home for all your data" : "een veilige plek voor al je gegevens",
-    "File is currently busy, please try again later" : "Bestandsverwerking bezig, probeer het later opnieuw",
     "Application is not enabled" : "De applicatie is niet ingeschakeld",
     "Authentication error" : "Authenticatiefout",
     "Token expired. Please reload page." : "Token verlopen.  Herlaad de pagina.",
@@ -223,20 +208,15 @@ OC.L10N.register(
     "Please ask your server administrator to install the module." : "Vraag je beheerder om de module te installeren.",
     "PHP setting \"%s\" is not set to \"%s\"." : "PHP instelling \"%s\" staat niet op \"%s\".",
     "Adjusting this setting in php.ini will make Nextcloud run again" : "Het aanpassen van deze instelling in php.ini zorgt ervoor dat Nextcloud weer start",
-    "libxml2 2.7.0 is at least required. Currently %s is installed." : "De minimale versie van libxml2 versie is 2.7.0. Momenteel is  versie%s geïnstalleerd.",
-    "To fix this issue update your libxml2 version and restart your web server." : "Om dit probleem op te lossen, moet je de libxml2 versie bijwerken en je webserver herstarten.",
+    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> is ingesteld op <code>%s</code> in plaats van de verwachte waarde <code>0</code>.",
+    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Om dit op te lossen stel je <code>mbstring.func_overload</code> in op <code>0</code> in je php.ini.",
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP is nu zo ingesteld dat 'inline doc blocks' worden gestript. Hierdoor worden verschillende hoofd modules onbruikbaar.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Dit wordt vermoedelijk veroorzaakt door een cache/accelerator, zoals Zend OPcache of eAccelerator.",
     "PHP modules have been installed, but they are still listed as missing?" : "PHP modules zijn geïnstalleerd, maar ze worden nog steeds als ontbrekend aangegeven?",
     "Please ask your server administrator to restart the web server." : "Vraag je beheerder de webserver opnieuw te starten.",
-    "PostgreSQL >= 9 required." : "PostgreSQL >= 9 is vereist.",
-    "Please upgrade your database version." : "Werk je databaseversie bij.",
-    "Your data directory is readable by other users." : "Je datamap is leesbaar voor andere gebruikers.",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Wijzig de machtiging in 0770 zodat de directory niet door andere gebruikers bekeken kan worden.",
     "Your data directory must be an absolute path." : "Je datamap moet een absolute bestandslocatie hebben.",
     "Check the value of \"datadirectory\" in your configuration." : "Controleer de waarde van \"datadirectory\" in je configuratie.",
     "Your data directory is invalid." : "Je datamap is ongeldig.",
-    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Zorg dat er een bestand genaamd \".ocdata\" in de hoofddirectory aanwezig is.",
     "Action \"%s\" not supported or implemented." : "Actie \"%s\" niet ondersteund of geïmplementeerd.",
     "Authentication failed, wrong token or provider ID given" : "Authenticatie mislukt, ongeldig token of provider ID opgegeven",
     "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "Er ontbreken parameters om de aanvraag uit te voeren. Ontbrekende parameters: \"%s\"",
@@ -248,28 +228,14 @@ OC.L10N.register(
     "Storage connection error. %s" : "Opslag verbindingsfout. %s",
     "Storage is temporarily not available" : "Opslag is tijdelijk niet beschikbaar",
     "Storage connection timeout. %s" : "Opslag verbinding time-out. %s",
-    "This can usually be fixed by giving the webserver write access to the config directory." : "Dit kan opgelost worden door de config map op de webserver schrijfrechten te geven.",
-    "%s enter the database username and name." : "%s voer de database gebruikersnaam en naam in .",
-    "%s enter the database username." : "%s voer de database gebruikersnaam in.",
-    "%s enter the database name." : "%s voer de databasenaam in.",
-    "%s you may not use dots in the database name" : "%s er mogen geen punten in de databasenaam voorkomen",
-    "Cannot read file" : "Kan bestand niet lezen",
-    "Cannot write into \"config\" directory" : "Kan niet schrijven naar de \"config\" directory",
-    "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "Dit kan opgelost worden door de config map op de webserver schrijf rechten te geven. See %s",
-    "Cannot write into \"apps\" directory" : "Kan niet schrijven naar de \"apps\" directory",
-    "This can usually be fixed by giving the webserver write access to the apps directory or disabling the App Store in the config file." : "Dit kan hersteld worden door de webserver schrijfrechten te geven op de appsdirectory of door de App Store te deactiveren in het configuratie bestand.",
-    "Cannot create \"data\" directory" : "\"data\" map kan niet worden aangemaakt",
-    "This can usually be fixed by giving the webserver write access to the root directory. See %s" : "Dit kan hersteld worden door de root map schrijf rechten te geven op de webserver. Zie %s",
-    "Permissions can usually be fixed by giving the webserver write access to the root directory. See %s." : "Machtigingen kunnen worden hersteld door de root map op de webserver schrijf toegang te geven. Zie %s.",
-    "Setting locale to %s failed" : "Instellen taal op %s mislukte",
-    "Please install one of these locales on your system and restart your webserver." : "Installeer één van de talen op je systeem en herstart je webserver.",
-    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload is ingesteld op \"%s\" in plaats van de verwachte waarde \"0\"",
-    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Om dit probleem op te lossen stel je in php.ini <code>mbstring.func_overload</code> in op <code>0</code>",
-    "PostgreSQL >= 9 required" : "PostgreSQL >= 9 is vereist",
-    "Please upgrade your database version" : "Werk je databaseversie bij",
-    "Your data directory is readable by other users" : "Je datamap is leesbaar voor andere gebruikers",
-    "Your data directory must be an absolute path" : "Je datamap moet een absolute bestandslocatie hebben",
-    "Check the value of \"datadirectory\" in your configuration" : "Controleer de waarde van \"datadirectory\" in je configuratie",
-    "Your data directory is invalid" : "Je datamap is ongeldig"
+    "Images" : "Afbeeldingen",
+    "Question" : "Vraag",
+    "Confirmation" : "Bevestiging",
+    "Text" : "Tekst",
+    "Summary" : "Samenvatting",
+    "Translate" : "Vertaal",
+    "Result" : "Resultaat",
+    "Organisation" : "Organisatie",
+    "File is currently busy, please try again later" : "Bestandsverwerking bezig, probeer het later opnieuw"
 },
 "nplurals=2; plural=(n != 1);");
