@@ -93,6 +93,8 @@ OC.L10N.register(
     "Destination does not exist" : "Destinationen finns inte",
     "Destination is not creatable" : "Destinationen går inte att skapa",
     "Dot files are not allowed" : "Dot-filer är inte tillåtna",
+    "%1$s (renamed)" : "%1$s (omdöpt)",
+    "renamed file" : "omdöpt fil",
     "\"%1$s\" is a forbidden file or folder name." : "\"%1$s\" är ett förbjudet fil- eller mappnamn.",
     "\"%1$s\" is a forbidden prefix for file or folder names." : "\"%1$s\" är ett förbjudet prefix för fil- eller mappnamn.",
     "\"%1$s\" is not allowed inside a file or folder name." : "\"%1$s\" är inte tillåtet i ett fil- eller mappnamn.",
@@ -142,7 +144,7 @@ OC.L10N.register(
     "About" : "Om",
     "Display name" : "Visningsnamn",
     "Headline" : "Rubrik",
-    "Organisation" : "Organisation",
+    "Organization" : "Organisering",
     "Role" : "Roll",
     "Pronouns" : "Pronomen",
     "Unknown account" : "Okänt konto",
@@ -201,6 +203,7 @@ OC.L10N.register(
     "Path is already shared with this group" : "Sökvägen delas redan med den här gruppen",
     "Link sharing is not allowed" : "Länkdelning är inte tillåtet",
     "Public upload is not allowed" : "Offentlig uppladdning är inte tillåten",
+    "You cannot share a folder that contains other shares" : "Du kan inte dela en mapp som innehåller andra delningar",
     "Sharing is disabled" : "Delning är inaktiverat",
     "Sharing is disabled for you" : "Delning är inaktiverat för dig",
     "Cannot share with the share owner" : "Kan inte dela med ägaren",
@@ -272,6 +275,7 @@ OC.L10N.register(
     "A valid Login must be provided" : "En giltig inloggning måste anges",
     "Login contains whitespace at the beginning or at the end" : "Inloggningen innehåller blanksteg i början eller slutet",
     "Login must not consist of dots only" : "Inloggningen får inte innehålla enbart punkter",
+    "Username is too long" : "Användarnamnet är för långt",
     "Login is invalid because files already exist for this user" : "Inloggningen är ogiltigt eftersom det redan finns filer för den här användaren",
     "Account disabled" : "Konto inaktiverat",
     "Login canceled by app" : "Inloggningen avbruten av appen",
@@ -322,17 +326,29 @@ OC.L10N.register(
     "Storage is temporarily not available" : "Lagringsutrymme är för tillfället inte tillgängligt",
     "Storage connection timeout. %s" : "Lagringsutrymme lyckas inte ansluta \"timeout\". %s",
     "To allow this check to run you have to make sure that your Web server can connect to itself. Therefore it must be able to resolve and connect to at least one of its `trusted_domains` or the `overwrite.cli.url`. This failure may be the result of a server-side DNS mismatch or outbound firewall rule." : "För att denna kontroll ska kunna köra måste du se till att webbservern kan ansluta till sig själv. Den måste alltså kunna finna och ansluta till minst en av sina \"trusted_domains\" eller \"overwrite.cli.url\":en. Detta misslyckande kan vara resultatet av en DNS missmatch på serversidan eller utgående brandväggs-regler.",
+    "Images" : "Bilder",
+    "Question" : "Fråga",
+    "Generated response" : "Genererat svar",
+    "System prompt" : "Systemuppmaning",
+    "Define rules and assumptions that the assistant should follow during the conversation." : "Definiera regler och antaganden som assistenten ska följa under samtalet.",
+    "Chat history" : "Chatthistorik",
     "Transcribe audio" : "Transkribera ljud",
     "Transcribe the things said in an audio" : "Transkribera det som sägs i ljud",
     "Audio input" : "Ljudinmatning",
     "The audio to transcribe" : "Ljudet att transkribera",
     "Transcription" : "Transkription",
     "The transcribed text" : "Den transkriberade texten",
+    "Confirmation" : "Bekräftelse",
+    "Whether to confirm previously requested actions: 0 for denial and 1 for confirmation." : "Om tidigare begärda åtgärder ska bekräftas: 0 för avslag och 1 för bekräftelse.",
+    "Conversation token" : "Konversationstoken",
+    "A token representing the conversation." : "En token som representerar konversationen.",
+    "The new conversation token" : "Den nya konversationstoken",
+    "Send this along with the next interaction." : "Skicka detta tillsammans med nästa interaktion.",
+    "Requested actions by the agent" : "Begärda åtgärder av agenten",
+    "Actions that the agent would like to carry out in JSON format." : "Åtgärder som agenten vill utföra i JSON-format.",
     "Chat with an agent" : "Chatta med en agent",
     "Chat message" : "Chattmeddelande",
     "A chat message to send to the agent." : "Ett chattmeddelande att skicka till agenten.",
-    "Confirmation" : "Bekräftelse",
-    "Generated response" : "Genererat svar",
     "The response from the chat model." : "Svaret från chattmodellen.",
     "Context write" : "Kontextuell skrivning",
     "Writes text in a given style based on the provided source material." : "Skriver text i en given stil baserat på det tillhandahållna källmaterialet.",
@@ -355,6 +371,11 @@ OC.L10N.register(
     "How many images to generate" : "Hur många bilder som ska genereras",
     "Output images" : "Skapade bilder",
     "The generated images" : "De genererade bilderna",
+    "Generate speech" : "Generera tal",
+    "Generate speech from a transcript" : "Generera tal från en transkription",
+    "Write transcript that you want the assistant to generate speech from" : "Skriv den transkription som du vill att assistenten ska generera tal från",
+    "Output speech" : "Genererat tal",
+    "The generated speech" : "Det genererade talet",
     "Free text to text prompt" : "Fritext till text prompt",
     "Runs an arbitrary prompt through a language model that returns a reply" : "Kör en godtycklig prompt genom en språkmodell som returnerar ett svar",
     "Describe a task that you want the assistant to do or ask a question" : "Beskriv en uppgift som du vill att assistenten ska göra eller ställ en fråga",
@@ -364,14 +385,22 @@ OC.L10N.register(
     "Change the tone of a piece of text." : "Ändra tonfallet i ett stycke text.",
     "Write a text that you want the assistant to rewrite in another tone." : "Skriv text som du vill att assistenten ska omformulera med ett annat tonfall.",
     "Desired tone" : "Önskat tonfall",
+    "In which tone should your text be rewritten?" : "I vilken ton ska din text skrivas om?",
+    "The rewritten text in the desired tone, written by the assistant:" : "Den omskrivna texten i önskad ton, skriven av assistenten:",
     "Chat" : "Chatt",
     "Chat with the assistant" : "Chatta med assistenten",
-    "System prompt" : "Systemuppmaning",
-    "Define rules and assumptions that the assistant should follow during the conversation." : "Definiera regler och antaganden som assistenten ska följa under samtalet.",
-    "Chat history" : "Chatthistorik",
     "The history of chat messages before the current message, starting with a message by the user" : "Historiken för chattmeddelanden före det aktuella meddelandet, som börjar med ett meddelande från användaren",
     "Response message" : "Svarsmeddelande",
     "The generated response as part of the conversation" : "Det genererade svaret som en del av konversationen",
+    "Chat with tools" : "Chatt med verktyg",
+    "Chat with the language model with tool calling support." : "Chatt med språkmodellen med stöd för verktygsanrop.",
+    "Tool message" : "Verktygsmeddelande",
+    "The result of tool calls in the last interaction" : "Resultatet av verktygsanropen i den senaste interaktionen",
+    "Available tools" : "Tillgängliga verktyg",
+    "The available tools in JSON format" : "Tillgängliga verktyg i JSON-format",
+    "The response from the chat model" : "Svaret från chattmodellen",
+    "Tool calls" : "Verktagsanrop",
+    "Tools call instructions from the model in JSON format" : "Verktygsanrop och instruktioner från modellen i JSON-format",
     "Formalize text" : "Formalisera text",
     "Takes a text and makes it sound more formal" : "Tar en text och får det att låta mer formellt",
     "Write a text that you want the assistant to formalize" : "Skriv en text som du vill att assistenten ska formalisera",
@@ -383,7 +412,11 @@ OC.L10N.register(
     "The original text to generate a headline for" : "Den ursprungliga texten att skapa en rubrik för",
     "The generated headline" : "Den skapade rubriken",
     "Proofread" : "Korrekturläs",
+    "Proofreads a text and lists corrections" : "Korrekturläser en text och listar korrigeringar",
     "Text" : "Text",
+    "The text to proofread" : "Texten som ska korrekturläsas",
+    "Corrections" : "Korrigeringar",
+    "The corrections that should be made in your text" : "Korrigeringarna som bör göras i din text",
     "Reformulate text" : "Omformulera text",
     "Takes a text and reformulates it" : "Tar en text och omformulerar den",
     "Write a text that you want the assistant to reformulate" : "Skriv en text som du vill att assistenten ska formulera om",
@@ -419,21 +452,9 @@ OC.L10N.register(
     "Generate headline" : "Skapa rubrik",
     "Summarizes text by reducing its length without losing key information." : "Sammanfattar text genom att minska dess längd utan att förlora viktig information.",
     "Extracts topics from a text and outputs them separated by commas." : "Extraherar ämnen från en text och matar ut dem separerade med kommatecken.",
-    "Education Edition" : "Utbildningspaket",
-    "File name is a reserved word" : "Filnamnet är ett reserverat ord",
-    "File name contains at least one invalid character" : "Filnamnet innehåller minst ett ogiltigt tecken",
-    "File name is too long" : "Filnamnet är för långt",
-    "Users" : "Användare",
-    "%1$s shared »%2$s« with you and wants to add:" : "%1$s delade \"%2$s\" med dig och vill lägga till:",
-    "%1$s shared »%2$s« with you and wants to add" : "%1$s delade \"%2$s\" med dig och vill lägga till",
-    "»%s« added a note to a file shared with you" : "\"%s\" lade till en kommentar till en fil som delats med dig",
-    "Open »%s«" : "Öppna \"%s\"",
-    "%1$s shared »%2$s« with you" : "%1$s delade \"%2$s\" med dig",
-    "%1$s shared »%2$s« with you." : "%1$s delade \"%2$s\" med dig.",
-    "Click the button below to open it." : "Klicka på knappen nedan för att öppna det.",
+    "Organisation" : "Organisation",
     "File is currently busy, please try again later" : "Filen är för tillfället upptagen, försök igen senare",
     "Cannot download file" : "Kan inte ladda ner fil",
-    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Säkerställ att du har filen \".ocdata\" i huvudkatalogen för din data.",
-    "Path contains files shared with you" : "Sökvägen innehåller filer som delas med dig"
+    "Login is too long" : "Inloggningen är för lång"
 },
 "nplurals=2; plural=(n != 1);");
